
# Before `make install' is performed this script should be runnable with
# `make test'. After `make install' it should work as `perl test.pl'

######################### We start with some black magic to print on failure.

# Change 1..1 below to 1..last_test_to_print .
# (It may become useful if the test is moved to ./t subdirectory.)

BEGIN { $| = 1; print "1..960\n"; }
END {print "not ok 1\n" unless $loaded;}
use Lingua::EN::Inflect qw( :ALL );
$loaded = 1;
print "ok 1\n";

my $count = 2;
sub ok($;$$)
{
    my $ok = $_[0];
    print "not " unless $ok;
    print "ok $count";
    print "\t# $_[1]" if $_[1];
    print " -> $_[2]" if $_[2];
    print "\n";
    $count++;
    return $ok;
}

sub is ($$;$$) 
{
    my $match = $_[0] eq $_[1];
    ok($match, $_[2], $_[3]);
    if (!$match) {
        print '# Expected: ' . $_[1]. "\n";
        print '# but got:  ' . $_[0]. "\n";
    }
}

sub diag {
    print "# @_\n";
}

######################### End of black magic.

sub test_eq($$)
{
    PL_eq($_[0],$_[1])    ||
    PL_N_eq($_[0],$_[1])  ||
    PL_V_eq($_[0],$_[1])  ||
    PL_ADJ_eq($_[0],$_[1]);
}


for my $thresh (0..20) {
    for my $n (0..20) {
        my $threshed = NUMWORDS($n, threshold=>$thresh);
        my $numwords = NUMWORDS($n);

        if ($n <= $thresh) {
            ok ( $numwords eq $threshed => "Wordified $n (<= $thresh)");
        }
        else {
            $threshed =~ s/\D//gxms;
            ok ( $threshed == $n => "Preserved $n (above $thresh)");
        }
    }
}

ok NUMWORDS(    999, threshold=>500) eq      '999',     ' 999 -> 999';
ok NUMWORDS(   1000, threshold=>500) eq    '1,000',     '1000 -> 1,000';
ok NUMWORDS(  10000, threshold=>500) eq   '10,000',    '10000 -> 10,000';
ok NUMWORDS( 100000, threshold=>500) eq  '100,000',   '100000 -> 100,000';
ok NUMWORDS(1000000, threshold=>500) eq '1,000,000', '1000000 -> 1,000,000';

ok NUMWORDS(    999.3, threshold=>500) eq      '999.3',     ' 999.3 -> 999.3';
ok NUMWORDS(   1000.3, threshold=>500) eq    '1,000.3',     '1000.3 -> 1,000.3';
ok NUMWORDS(  10000.3, threshold=>500) eq   '10,000.3',    '10000.3 -> 10,000.3';
ok NUMWORDS( 100000.3, threshold=>500) eq  '100,000.3',   '100000.3 -> 100,000.3';
ok NUMWORDS(1000000.3, threshold=>500) eq '1,000,000.3', '1000000.3 -> 1,000,000.3';

ok NUMWORDS(    999, threshold=>500, comma=>0) eq      '999',     ' 999 -> 999';
ok NUMWORDS(   1000, threshold=>500, comma=>0) eq    '1000',     '1000 -> 1000';
ok NUMWORDS(  10000, threshold=>500, comma=>0) eq   '10000',    '10000 -> 10000';
ok NUMWORDS( 100000, threshold=>500, comma=>0) eq  '100000',   '100000 -> 100000';
ok NUMWORDS(1000000, threshold=>500, comma=>0) eq '1000000', '1000000 -> 1000000';

ok NUMWORDS(    999.3, threshold=>500, comma=>0) eq      '999.3',     ' 999.3 -> 999.3';
ok NUMWORDS(   1000.3, threshold=>500, comma=>0) eq    '1000.3',     '1000.3 -> 1000.3';
ok NUMWORDS(  10000.3, threshold=>500, comma=>0) eq   '10000.3',    '10000.3 -> 10000.3';
ok NUMWORDS( 100000.3, threshold=>500, comma=>0) eq  '100000.3',   '100000.3 -> 100000.3';
ok NUMWORDS(1000000.3, threshold=>500, comma=>0) eq '1000000.3', '1000000.3 -> 1000000.3';



NUMBER:
for my $i (0..$#nw)
{
    is ( NUMWORDS($nw[$i][0])          , $nw[$i][1], "$nw[$i][0] -> $nw[$i][1]..." );
    is ( NUMWORDS($nw[$i][0], group=>1), $nw[$i][2], '...group=>1' );
    is ( NUMWORDS($nw[$i][0], group=>2), $nw[$i][3], '...group=>2' );
    is ( NUMWORDS($nw[$i][0], group=>3), $nw[$i][4], '...group=>2' );
    is ( NUMWORDS(ORD($nw[$i][0]))     , $nw[$i][5], '...ordinal' ) if $nw[$i][5];
    is ( ORD(NUMWORDS($nw[$i][0]))     , ($nw[$i][6]||$nw[$i][5]), '...ordinal inverted' )
                            if $nw[$i][6]||$nw[$i][5];

    ok !eval { NUMWORDS(42, and=>); 1; } => '...missing arg';
    ok $@ =~ 'odd number of' => '...has correct error';

    my $count = $nw[$i][0];      # Remove non-number chars
    $count =~ s{[^\d.e+-]}{}gi;  # Remove extra decimal points after the first
    1 while $count =~ s{([.].*)[.]}{$1};
    ok ( NO('cat', $count, {words_below=>100})
            =~ ( $count == 0  ? 'no cat'
               : $count == 1  ? 'one cat'
               : $count < 100 ? "$nw[$i][1] cats"
               :                "$count cats") => '...words_below=>100');
}

BEGIN
{
    @nw =
    (
    [
        "0",
        "zero",
        "zero",
        "zero",
        "zero",
        "zeroth",
    ],[
        "1",
        "one",
        "one",
        "one",
        "one",
        "first",
    ],[
        "2",
        "two",
        "two",
        "two",
        "two",
        "second",
    ],[
        "3",
        "three",
        "three",
        "three",
        "three",
        "third",
    ],[
        "4",
        "four",
        "four",
        "four",
        "four",
        "fourth",
    ],[
        "5",
        "five",
        "five",
        "five",
        "five",
        "fifth",
    ],[
        "6",
        "six",
        "six",
        "six",
        "six",
        "sixth",
    ],[
        "7",
        "seven",
        "seven",
        "seven",
        "seven",
        "seventh",
    ],[
        "8",
        "eight",
        "eight",
        "eight",
        "eight",
        "eighth",
    ],[
        "9",
        "nine",
        "nine",
        "nine",
        "nine",
        "ninth",
    ],[
        "10",
        "ten",
        "one, zero",
        "ten",
        "ten",
        "tenth",
    ],[
        "11",
        "eleven",
        "one, one",
        "eleven",
        "eleven",
        "eleventh",
    ],[
        "12",
        "twelve",
        "one, two",
        "twelve",
        "twelve",
        "twelfth",
    ],[
        "13",
        "thirteen",
        "one, three",
        "thirteen",
        "thirteen",
        "thirteenth",
    ],[
        "14",
        "fourteen",
        "one, four",
        "fourteen",
        "fourteen",
        "fourteenth",
    ],[
        "15",
        "fifteen",
        "one, five",
        "fifteen",
        "fifteen",
        "fifteenth",
    ],[
        "16",
        "sixteen",
        "one, six",
        "sixteen",
        "sixteen",
        "sixteenth",
    ],[
        "17",
        "seventeen",
        "one, seven",
        "seventeen",
        "seventeen",
        "seventeenth",
    ],[
        "18",
        "eighteen",
        "one, eight",
        "eighteen",
        "eighteen",
        "eighteenth",
    ],[
        "19",
        "nineteen",
        "one, nine",
        "nineteen",
        "nineteen",
        "nineteenth",
    ],[
        "20",
        "twenty",
        "two, zero",
        "twenty",
        "twenty",
        "twentieth",
    ],[
        "21",
        "twenty-one",
        "two, one",
        "twenty-one",
        "twenty-one",
        "twenty-first",
    ],[
        "29",
        "twenty-nine",
        "two, nine",
        "twenty-nine",
        "twenty-nine",
        "twenty-ninth",
    ],[
        "99",
        "ninety-nine",
        "nine, nine",
        "ninety-nine",
        "ninety-nine",
        "ninety-ninth",
    ],[
        "100",
        "one hundred",
        "one, zero, zero",
        "ten, zero",
        "one zero zero",
        "one hundredth"
    ],[
        "101",
        "one hundred and one",
        "one, zero, one",
        "ten, one",
        "one zero one",
        "one hundred and first"
    ],[
        "110",
        "one hundred and ten",
        "one, one, zero",
        "eleven, zero",
        "one ten",
        "one hundred and tenth",
    ],[
        "111",
        "one hundred and eleven",
        "one, one, one",
        "eleven, one",
        "one eleven",
        "one hundred and eleventh",
    ],[
        "900",
        "nine hundred",
        "nine, zero, zero",
        "ninety, zero",
        "nine zero zero",
        "nine hundredth",
    ],[
        "999",
        "nine hundred and ninety-nine",
        "nine, nine, nine",
        "ninety-nine, nine",
        "nine ninety-nine",
        "nine hundred and ninety-ninth",
    ],[
        "1000",
        "one thousand",
        "one, zero, zero, zero",
        "ten, zero zero",
        "one zero zero, zero",
        "one thousandth",
    ],[
        "1001",
        "one thousand and one",
        "one, zero, zero, one",
        "ten, zero one",
        "one zero zero, one",
        "one thousand and first",
    ],[
        "1010",
        "one thousand and ten",
        "one, zero, one, zero",
        "ten, ten",
        "one zero one, zero",
        "one thousand and tenth",
    ],[
        "1100",
        "one thousand, one hundred",
        "one, one, zero, zero",
        "eleven, zero zero",
        "one ten, zero",
        "one thousand, one hundredth",
    ],[
        "2000",
        "two thousand",
        "two, zero, zero, zero",
        "twenty, zero zero",
        "two zero zero, zero",
        "two thousandth",
    ],[
        "10000",
        "ten thousand",
        "one, zero, zero, zero, zero",
        "ten, zero zero, zero",
        "one zero zero, zero zero",
        "ten thousandth",
    ],[
        "100000",
        "one hundred thousand",
        "one, zero, zero, zero, zero, zero",
        "ten, zero zero, zero zero",
        "one zero zero, zero zero zero",
        "one hundred thousandth",
    ],[
        "100001",
        "one hundred thousand and one",
        "one, zero, zero, zero, zero, one",
        "ten, zero zero, zero one",
        "one zero zero, zero zero one",
        "one hundred thousand and first",
    ],[
        "123456",
        "one hundred and twenty-three thousand, four hundred and fifty-six",
        "one, two, three, four, five, six",
        "twelve, thirty-four, fifty-six",
        "one twenty-three, four fifty-six",
        "one hundred and twenty-three thousand, four hundred and fifty-sixth",
    ],[
        "0123456",
        "one hundred and twenty-three thousand, four hundred and fifty-six",
        "zero, one, two, three, four, five, six",
        "zero one, twenty-three, forty-five, six",
        "zero twelve, three forty-five, six",
        "one hundred and twenty-three thousand, four hundred and fifty-sixth",
    ],[
        "1234567",
        "one million, two hundred and thirty-four thousand, five hundred and sixty-seven",
        "one, two, three, four, five, six, seven",
        "twelve, thirty-four, fifty-six, seven",
        "one twenty-three, four fifty-six, seven",
        "one million, two hundred and thirty-four thousand, five hundred and sixty-seventh",
    ],[
        "12345678",
        "twelve million, three hundred and forty-five thousand, six hundred and seventy-eight",
        "one, two, three, four, five, six, seven, eight",
        "twelve, thirty-four, fifty-six, seventy-eight",
        "one twenty-three, four fifty-six, seventy-eight",
        "twelve million, three hundred and forty-five thousand, six hundred and seventy-eighth",
    ],[
        "12_345_678",
        "twelve million, three hundred and forty-five thousand, six hundred and seventy-eight",
        "one, two, three, four, five, six, seven, eight",
        "twelve, thirty-four, fifty-six, seventy-eight",
        "one twenty-three, four fifty-six, seventy-eight",
    ],[
        "1234,5678",
        "twelve million, three hundred and forty-five thousand, six hundred and seventy-eight",
        "one, two, three, four, five, six, seven, eight",
        "twelve, thirty-four, fifty-six, seventy-eight",
        "one twenty-three, four fifty-six, seventy-eight",
    ],[
        "1234567890",
        "one billion, two hundred and thirty-four million, five hundred and sixty-seven thousand, eight hundred and ninety",
        "one, two, three, four, five, six, seven, eight, nine, zero",
        "twelve, thirty-four, fifty-six, seventy-eight, ninety",
        "one twenty-three, four fifty-six, seven eighty-nine, zero",
        "one billion, two hundred and thirty-four million, five hundred and sixty-seven thousand, eight hundred and ninetieth",
    ],[
        "123456789012345",
        "one hundred and twenty-three trillion, four hundred and fifty-six billion, seven hundred and eighty-nine million, twelve thousand, three hundred and forty-five",
        "one, two, three, four, five, six, seven, eight, nine, zero, one, two, three, four, five",
        "twelve, thirty-four, fifty-six, seventy-eight, ninety, twelve, thirty-four, five",
        "one twenty-three, four fifty-six, seven eighty-nine, zero twelve, three forty-five",
        "one hundred and twenty-three trillion, four hundred and fifty-six billion, seven hundred and eighty-nine million, twelve thousand, three hundred and forty-fifth",
    ],[
        "12345678901234567890",
        "twelve quintillion, three hundred and forty-five quadrillion, six hundred and seventy-eight trillion, nine hundred and one billion, two hundred and thirty-four million, five hundred and sixty-seven thousand, eight hundred and ninety",
        "one, two, three, four, five, six, seven, eight, nine, zero, one, two, three, four, five, six, seven, eight, nine, zero",
        "twelve, thirty-four, fifty-six, seventy-eight, ninety, twelve, thirty-four, fifty-six, seventy-eight, ninety",
        "one twenty-three, four fifty-six, seven eighty-nine, zero twelve, three forty-five, six seventy-eight, ninety",
        "twelve quintillion, three hundred and forty-five quadrillion, six hundred and seventy-eight trillion, nine hundred and one billion, two hundred and thirty-four million, five hundred and sixty-seven thousand, eight hundred and ninetieth",
    ],[
        "0.987654",
        "zero point nine eight seven six five four",
        "zero, point, nine, eight, seven, six, five, four",
        "zero, point, ninety-eight, seventy-six, fifty-four",
        "zero, point, nine eighty-seven, six fifty-four",
        "zeroth point nine eight seven six five four",
        "zero point nine eight seven six five fourth",
    ],[
        ".987654",
        "point nine eight seven six five four",
        "point, nine, eight, seven, six, five, four",
        "point, ninety-eight, seventy-six, fifty-four",
        "point, nine eighty-seven, six fifty-four",
        "point nine eight seven six five four",
        "point nine eight seven six five fourth",
    ],[
        "9.87654",
        "nine point eight seven six five four",
        "nine, point, eight, seven, six, five, four",
        "nine, point, eighty-seven, sixty-five, four",
        "nine, point, eight seventy-six, fifty-four",
        "ninth point eight seven six five four",
        "nine point eight seven six five fourth",
    ],[
        "98.7654",
        "ninety-eight point seven six five four",
        "nine, eight, point, seven, six, five, four",
        "ninety-eight, point, seventy-six, fifty-four",
        "ninety-eight, point, seven sixty-five, four",
        "ninety-eighth point seven six five four",
        "ninety-eight point seven six five fourth",
    ],[
        "987.654",
        "nine hundred and eighty-seven point six five four",
        "nine, eight, seven, point, six, five, four",
        "ninety-eight, seven, point, sixty-five, four",
        "nine eighty-seven, point, six fifty-four",
        "nine hundred and eighty-seventh point six five four",
        "nine hundred and eighty-seven point six five fourth",
    ],[
        "9876.54",
        "nine thousand, eight hundred and seventy-six point five four",
        "nine, eight, seven, six, point, five, four",
        "ninety-eight, seventy-six, point, fifty-four",
        "nine eighty-seven, six, point, fifty-four",
        "nine thousand, eight hundred and seventy-sixth point five four",
        "nine thousand, eight hundred and seventy-six point five fourth",
    ],[
        "98765.4",
        "ninety-eight thousand, seven hundred and sixty-five point four",
        "nine, eight, seven, six, five, point, four",
        "ninety-eight, seventy-six, five, point, four",
        "nine eighty-seven, sixty-five, point, four",
        "ninety-eight thousand, seven hundred and sixty-fifth point four",
        "ninety-eight thousand, seven hundred and sixty-five point fourth",
    ],[
        "101.202.303",
        "one hundred and one point two zero two three zero three",
        "one, zero, one, point, two, zero, two, point, three, zero, three",
        "ten, one, point, twenty, two, point, thirty, three",
        "one zero one, point, two zero two, point, three zero three",
    ],[
        '1234567890' x 300,
        "one hundred and twenty-three sextillion nonagintillion nongentillion, four hundred and fifty-six quintillion nonagintillion nongentillion, seven hundred and eighty-nine quadrillion nonagintillion nongentillion, twelve trillion nonagintillion nongentillion, three hundred and forty-five billion nonagintillion nongentillion, six hundred and seventy-eight million nonagintillion nongentillion, nine hundred and one thousand nonagintillion nongentillion, two hundred and thirty-four nonagintillion nongentillion, five hundred and sixty-seven octillion octogintillion nongentillion, eight hundred and ninety septillion octogintillion nongentillion, one hundred and twenty-three sextillion octogintillion nongentillion, four hundred and fifty-six quintillion octogintillion nongentillion, seven hundred and eighty-nine quadrillion octogintillion nongentillion, twelve trillion octogintillion nongentillion, three hundred and forty-five billion octogintillion nongentillion, six hundred and seventy-eight million octogintillion nongentillion, nine hundred and one thousand octogintillion nongentillion, two hundred and thirty-four octogintillion nongentillion, five hundred and sixty-seven octillion septuagintillion nongentillion, eight hundred and ninety septillion septuagintillion nongentillion, one hundred and twenty-three sextillion septuagintillion nongentillion, four hundred and fifty-six quintillion septuagintillion nongentillion, seven hundred and eighty-nine quadrillion septuagintillion nongentillion, twelve trillion septuagintillion nongentillion, three hundred and forty-five billion septuagintillion nongentillion, six hundred and seventy-eight million septuagintillion nongentillion, nine hundred and one thousand septuagintillion nongentillion, two hundred and thirty-four septuagintillion nongentillion, five hundred and sixty-seven octillion sexagintillion nongentillion, eight hundred and ninety septillion sexagintillion nongentillion, one hundred and twenty-three sextillion sexagintillion nongentillion, four hundred and fifty-six quintillion sexagintillion nongentillion, seven hundred and eighty-nine quadrillion sexagintillion nongentillion, twelve trillion sexagintillion nongentillion, three hundred and forty-five billion sexagintillion nongentillion, six hundred and seventy-eight million sexagintillion nongentillion, nine hundred and one thousand sexagintillion nongentillion, two hundred and thirty-four sexagintillion nongentillion, five hundred and sixty-seven octillion quinquagintillion nongentillion, eight hundred and ninety septillion quinquagintillion nongentillion, one hundred and twenty-three sextillion quinquagintillion nongentillion, four hundred and fifty-six quintillion quinquagintillion nongentillion, seven hundred and eighty-nine quadrillion quinquagintillion nongentillion, twelve trillion quinquagintillion nongentillion, three hundred and forty-five billion quinquagintillion nongentillion, six hundred and seventy-eight million quinquagintillion nongentillion, nine hundred and one thousand quinquagintillion nongentillion, two hundred and thirty-four quinquagintillion nongentillion, five hundred and sixty-seven octillion quadragintillion nongentillion, eight hundred and ninety septillion quadragintillion nongentillion, one hundred and twenty-three sextillion quadragintillion nongentillion, four hundred and fifty-six quintillion quadragintillion nongentillion, seven hundred and eighty-nine quadrillion quadragintillion nongentillion, twelve trillion quadragintillion nongentillion, three hundred and forty-five billion quadragintillion nongentillion, six hundred and seventy-eight million quadragintillion nongentillion, nine hundred and one thousand quadragintillion nongentillion, two hundred and thirty-four quadragintillion nongentillion, five hundred and sixty-seven noventrigintillion nongentillion, eight hundred and ninety octotrigintillion nongentillion, one hundred and twenty-three septentrigintillion nongentillion, four hundred and fifty-six sestrigintillion nongentillion, seven hundred and eighty-nine quinquatrigintillion nongentillion, twelve quattuortrigintillion nongentillion, three hundred and forty-five trestrigintillion nongentillion, six hundred and seventy-eight duotrigintillion nongentillion, nine hundred and one untrigintillion nongentillion, two hundred and thirty-four trigintillion nongentillion, five hundred and sixty-seven novemvigintillion nongentillion, eight hundred and ninety octovigintillion nongentillion, one hundred and twenty-three septemvigintillion nongentillion, four hundred and fifty-six sesvigintillion nongentillion, seven hundred and eighty-nine quinquavigintillion nongentillion, twelve quattuorvigintillion nongentillion, three hundred and forty-five tresvigintillion nongentillion, six hundred and seventy-eight duovigintillion nongentillion, nine hundred and one unvigintillion nongentillion, two hundred and thirty-four vigintillion nongentillion, five hundred and sixty-seven novendecillion nongentillion, eight hundred and ninety octodecillion nongentillion, one hundred and twenty-three septendecillion nongentillion, four hundred and fifty-six sedecillion nongentillion, seven hundred and eighty-nine quindecillion nongentillion, twelve quattuordecillion nongentillion, three hundred and forty-five tredecillion nongentillion, six hundred and seventy-eight duodecillion nongentillion, nine hundred and one undecillion nongentillion, two hundred and thirty-four decillion nongentillion, five hundred and sixty-seven nonillion nongentillion, eight hundred and ninety octillion nongentillion, one hundred and twenty-three septillion nongentillion, four hundred and fifty-six sextillion nongentillion, seven hundred and eighty-nine quintillion nongentillion, twelve quadrillion nongentillion, three hundred and forty-five trillion nongentillion, six hundred and seventy-eight billion nongentillion, nine hundred and one million nongentillion, two hundred and thirty-four thousand nongentillion, five hundred and sixty-seven nongentillion, eight hundred and ninety septillion nonagintillion octingentillion, one hundred and twenty-three sextillion nonagintillion octingentillion, four hundred and fifty-six quintillion nonagintillion octingentillion, seven hundred and eighty-nine quadrillion nonagintillion octingentillion, twelve trillion nonagintillion octingentillion, three hundred and forty-five billion nonagintillion octingentillion, six hundred and seventy-eight million nonagintillion octingentillion, nine hundred and one thousand nonagintillion octingentillion, two hundred and thirty-four nonagintillion octingentillion, five hundred and sixty-seven octillion octogintillion octingentillion, eight hundred and ninety septillion octogintillion octingentillion, one hundred and twenty-three sextillion octogintillion octingentillion, four hundred and fifty-six quintillion octogintillion octingentillion, seven hundred and eighty-nine quadrillion octogintillion octingentillion, twelve trillion octogintillion octingentillion, three hundred and forty-five billion octogintillion octingentillion, six hundred and seventy-eight million octogintillion octingentillion, nine hundred and one thousand octogintillion octingentillion, two hundred and thirty-four octogintillion octingentillion, five hundred and sixty-seven octillion septuagintillion octingentillion, eight hundred and ninety septillion septuagintillion octingentillion, one hundred and twenty-three sextillion septuagintillion octingentillion, four hundred and fifty-six quintillion septuagintillion octingentillion, seven hundred and eighty-nine quadrillion septuagintillion octingentillion, twelve trillion septuagintillion octingentillion, three hundred and forty-five billion septuagintillion octingentillion, six hundred and seventy-eight million septuagintillion octingentillion, nine hundred and one thousand septuagintillion octingentillion, two hundred and thirty-four septuagintillion octingentillion, five hundred and sixty-seven octillion sexagintillion octingentillion, eight hundred and ninety septillion sexagintillion octingentillion, one hundred and twenty-three sextillion sexagintillion octingentillion, four hundred and fifty-six quintillion sexagintillion octingentillion, seven hundred and eighty-nine quadrillion sexagintillion octingentillion, twelve trillion sexagintillion octingentillion, three hundred and forty-five billion sexagintillion octingentillion, six hundred and seventy-eight million sexagintillion octingentillion, nine hundred and one thousand sexagintillion octingentillion, two hundred and thirty-four sexagintillion octingentillion, five hundred and sixty-seven octillion quinquagintillion octingentillion, eight hundred and ninety septillion quinquagintillion octingentillion, one hundred and twenty-three sextillion quinquagintillion octingentillion, four hundred and fifty-six quintillion quinquagintillion octingentillion, seven hundred and eighty-nine quadrillion quinquagintillion octingentillion, twelve trillion quinquagintillion octingentillion, three hundred and forty-five billion quinquagintillion octingentillion, six hundred and seventy-eight million quinquagintillion octingentillion, nine hundred and one thousand quinquagintillion octingentillion, two hundred and thirty-four quinquagintillion octingentillion, five hundred and sixty-seven octillion quadragintillion octingentillion, eight hundred and ninety septillion quadragintillion octingentillion, one hundred and twenty-three sextillion quadragintillion octingentillion, four hundred and fifty-six quintillion quadragintillion octingentillion, seven hundred and eighty-nine quadrillion quadragintillion octingentillion, twelve trillion quadragintillion octingentillion, three hundred and forty-five billion quadragintillion octingentillion, six hundred and seventy-eight million quadragintillion octingentillion, nine hundred and one thousand quadragintillion octingentillion, two hundred and thirty-four quadragintillion octingentillion, five hundred and sixty-seven noventrigintillion octingentillion, eight hundred and ninety octotrigintillion octingentillion, one hundred and twenty-three septentrigintillion octingentillion, four hundred and fifty-six sestrigintillion octingentillion, seven hundred and eighty-nine quinquatrigintillion octingentillion, twelve quattuortrigintillion octingentillion, three hundred and forty-five trestrigintillion octingentillion, six hundred and seventy-eight duotrigintillion octingentillion, nine hundred and one untrigintillion octingentillion, two hundred and thirty-four trigintillion octingentillion, five hundred and sixty-seven novemvigintillion octingentillion, eight hundred and ninety octovigintillion octingentillion, one hundred and twenty-three septemvigintillion octingentillion, four hundred and fifty-six sesvigintillion octingentillion, seven hundred and eighty-nine quinquavigintillion octingentillion, twelve quattuorvigintillion octingentillion, three hundred and forty-five tresvigintillion octingentillion, six hundred and seventy-eight duovigintillion octingentillion, nine hundred and one unvigintillion octingentillion, two hundred and thirty-four vigintillion octingentillion, five hundred and sixty-seven novendecillion octingentillion, eight hundred and ninety octodecillion octingentillion, one hundred and twenty-three septendecillion octingentillion, four hundred and fifty-six sedecillion octingentillion, seven hundred and eighty-nine quindecillion octingentillion, twelve quattuordecillion octingentillion, three hundred and forty-five tredecillion octingentillion, six hundred and seventy-eight duodecillion octingentillion, nine hundred and one undecillion octingentillion, two hundred and thirty-four decillion octingentillion, five hundred and sixty-seven nonillion octingentillion, eight hundred and ninety octillion octingentillion, one hundred and twenty-three septillion octingentillion, four hundred and fifty-six sextillion octingentillion, seven hundred and eighty-nine quintillion octingentillion, twelve quadrillion octingentillion, three hundred and forty-five trillion octingentillion, six hundred and seventy-eight billion octingentillion, nine hundred and one million octingentillion, two hundred and thirty-four thousand octingentillion, five hundred and sixty-seven octingentillion, eight hundred and ninety septillion nonagintillion septingentillion, one hundred and twenty-three sextillion nonagintillion septingentillion, four hundred and fifty-six quintillion nonagintillion septingentillion, seven hundred and eighty-nine quadrillion nonagintillion septingentillion, twelve trillion nonagintillion septingentillion, three hundred and forty-five billion nonagintillion septingentillion, six hundred and seventy-eight million nonagintillion septingentillion, nine hundred and one thousand nonagintillion septingentillion, two hundred and thirty-four nonagintillion septingentillion, five hundred and sixty-seven octillion octogintillion septingentillion, eight hundred and ninety septillion octogintillion septingentillion, one hundred and twenty-three sextillion octogintillion septingentillion, four hundred and fifty-six quintillion octogintillion septingentillion, seven hundred and eighty-nine quadrillion octogintillion septingentillion, twelve trillion octogintillion septingentillion, three hundred and forty-five billion octogintillion septingentillion, six hundred and seventy-eight million octogintillion septingentillion, nine hundred and one thousand octogintillion septingentillion, two hundred and thirty-four octogintillion septingentillion, five hundred and sixty-seven octillion septuagintillion septingentillion, eight hundred and ninety septillion septuagintillion septingentillion, one hundred and twenty-three sextillion septuagintillion septingentillion, four hundred and fifty-six quintillion septuagintillion septingentillion, seven hundred and eighty-nine quadrillion septuagintillion septingentillion, twelve trillion septuagintillion septingentillion, three hundred and forty-five billion septuagintillion septingentillion, six hundred and seventy-eight million septuagintillion septingentillion, nine hundred and one thousand septuagintillion septingentillion, two hundred and thirty-four septuagintillion septingentillion, five hundred and sixty-seven octillion sexagintillion septingentillion, eight hundred and ninety septillion sexagintillion septingentillion, one hundred and twenty-three sextillion sexagintillion septingentillion, four hundred and fifty-six quintillion sexagintillion septingentillion, seven hundred and eighty-nine quadrillion sexagintillion septingentillion, twelve trillion sexagintillion septingentillion, three hundred and forty-five billion sexagintillion septingentillion, six hundred and seventy-eight million sexagintillion septingentillion, nine hundred and one thousand sexagintillion septingentillion, two hundred and thirty-four sexagintillion septingentillion, five hundred and sixty-seven octillion quinquagintillion septingentillion, eight hundred and ninety septillion quinquagintillion septingentillion, one hundred and twenty-three sextillion quinquagintillion septingentillion, four hundred and fifty-six quintillion quinquagintillion septingentillion, seven hundred and eighty-nine quadrillion quinquagintillion septingentillion, twelve trillion quinquagintillion septingentillion, three hundred and forty-five billion quinquagintillion septingentillion, six hundred and seventy-eight million quinquagintillion septingentillion, nine hundred and one thousand quinquagintillion septingentillion, two hundred and thirty-four quinquagintillion septingentillion, five hundred and sixty-seven octillion quadragintillion septingentillion, eight hundred and ninety septillion quadragintillion septingentillion, one hundred and twenty-three sextillion quadragintillion septingentillion, four hundred and fifty-six quintillion quadragintillion septingentillion, seven hundred and eighty-nine quadrillion quadragintillion septingentillion, twelve trillion quadragintillion septingentillion, three hundred and forty-five billion quadragintillion septingentillion, six hundred and seventy-eight million quadragintillion septingentillion, nine hundred and one thousand quadragintillion septingentillion, two hundred and thirty-four quadragintillion septingentillion, five hundred and sixty-seven noventrigintillion septingentillion, eight hundred and ninety octotrigintillion septingentillion, one hundred and twenty-three septentrigintillion septingentillion, four hundred and fifty-six sestrigintillion septingentillion, seven hundred and eighty-nine quinquatrigintillion septingentillion, twelve quattuortrigintillion septingentillion, three hundred and forty-five trestrigintillion septingentillion, six hundred and seventy-eight duotrigintillion septingentillion, nine hundred and one untrigintillion septingentillion, two hundred and thirty-four trigintillion septingentillion, five hundred and sixty-seven novemvigintillion septingentillion, eight hundred and ninety octovigintillion septingentillion, one hundred and twenty-three septemvigintillion septingentillion, four hundred and fifty-six sesvigintillion septingentillion, seven hundred and eighty-nine quinquavigintillion septingentillion, twelve quattuorvigintillion septingentillion, three hundred and forty-five tresvigintillion septingentillion, six hundred and seventy-eight duovigintillion septingentillion, nine hundred and one unvigintillion septingentillion, two hundred and thirty-four vigintillion septingentillion, five hundred and sixty-seven novendecillion septingentillion, eight hundred and ninety octodecillion septingentillion, one hundred and twenty-three septendecillion septingentillion, four hundred and fifty-six sedecillion septingentillion, seven hundred and eighty-nine quindecillion septingentillion, twelve quattuordecillion septingentillion, three hundred and forty-five tredecillion septingentillion, six hundred and seventy-eight duodecillion septingentillion, nine hundred and one undecillion septingentillion, two hundred and thirty-four decillion septingentillion, five hundred and sixty-seven nonillion septingentillion, eight hundred and ninety octillion septingentillion, one hundred and twenty-three septillion septingentillion, four hundred and fifty-six sextillion septingentillion, seven hundred and eighty-nine quintillion septingentillion, twelve quadrillion septingentillion, three hundred and forty-five trillion septingentillion, six hundred and seventy-eight billion septingentillion, nine hundred and one million septingentillion, two hundred and thirty-four thousand septingentillion, five hundred and sixty-seven septingentillion, eight hundred and ninety septillion nonagintillion sescentillion, one hundred and twenty-three sextillion nonagintillion sescentillion, four hundred and fifty-six quintillion nonagintillion sescentillion, seven hundred and eighty-nine quadrillion nonagintillion sescentillion, twelve trillion nonagintillion sescentillion, three hundred and forty-five billion nonagintillion sescentillion, six hundred and seventy-eight million nonagintillion sescentillion, nine hundred and one thousand nonagintillion sescentillion, two hundred and thirty-four nonagintillion sescentillion, five hundred and sixty-seven octillion octogintillion sescentillion, eight hundred and ninety septillion octogintillion sescentillion, one hundred and twenty-three sextillion octogintillion sescentillion, four hundred and fifty-six quintillion octogintillion sescentillion, seven hundred and eighty-nine quadrillion octogintillion sescentillion, twelve trillion octogintillion sescentillion, three hundred and forty-five billion octogintillion sescentillion, six hundred and seventy-eight million octogintillion sescentillion, nine hundred and one thousand octogintillion sescentillion, two hundred and thirty-four octogintillion sescentillion, five hundred and sixty-seven octillion septuagintillion sescentillion, eight hundred and ninety septillion septuagintillion sescentillion, one hundred and twenty-three sextillion septuagintillion sescentillion, four hundred and fifty-six quintillion septuagintillion sescentillion, seven hundred and eighty-nine quadrillion septuagintillion sescentillion, twelve trillion septuagintillion sescentillion, three hundred and forty-five billion septuagintillion sescentillion, six hundred and seventy-eight million septuagintillion sescentillion, nine hundred and one thousand septuagintillion sescentillion, two hundred and thirty-four septuagintillion sescentillion, five hundred and sixty-seven octillion sexagintillion sescentillion, eight hundred and ninety septillion sexagintillion sescentillion, one hundred and twenty-three sextillion sexagintillion sescentillion, four hundred and fifty-six quintillion sexagintillion sescentillion, seven hundred and eighty-nine quadrillion sexagintillion sescentillion, twelve trillion sexagintillion sescentillion, three hundred and forty-five billion sexagintillion sescentillion, six hundred and seventy-eight million sexagintillion sescentillion, nine hundred and one thousand sexagintillion sescentillion, two hundred and thirty-four sexagintillion sescentillion, five hundred and sixty-seven octillion quinquagintillion sescentillion, eight hundred and ninety septillion quinquagintillion sescentillion, one hundred and twenty-three sextillion quinquagintillion sescentillion, four hundred and fifty-six quintillion quinquagintillion sescentillion, seven hundred and eighty-nine quadrillion quinquagintillion sescentillion, twelve trillion quinquagintillion sescentillion, three hundred and forty-five billion quinquagintillion sescentillion, six hundred and seventy-eight million quinquagintillion sescentillion, nine hundred and one thousand quinquagintillion sescentillion, two hundred and thirty-four quinquagintillion sescentillion, five hundred and sixty-seven octillion quadragintillion sescentillion, eight hundred and ninety septillion quadragintillion sescentillion, one hundred and twenty-three sextillion quadragintillion sescentillion, four hundred and fifty-six quintillion quadragintillion sescentillion, seven hundred and eighty-nine quadrillion quadragintillion sescentillion, twelve trillion quadragintillion sescentillion, three hundred and forty-five billion quadragintillion sescentillion, six hundred and seventy-eight million quadragintillion sescentillion, nine hundred and one thousand quadragintillion sescentillion, two hundred and thirty-four quadragintillion sescentillion, five hundred and sixty-seven noventrigintillion sescentillion, eight hundred and ninety octotrigintillion sescentillion, one hundred and twenty-three septentrigintillion sescentillion, four hundred and fifty-six sestrigintillion sescentillion, seven hundred and eighty-nine quinquatrigintillion sescentillion, twelve quattuortrigintillion sescentillion, three hundred and forty-five trestrigintillion sescentillion, six hundred and seventy-eight duotrigintillion sescentillion, nine hundred and one untrigintillion sescentillion, two hundred and thirty-four trigintillion sescentillion, five hundred and sixty-seven novemvigintillion sescentillion, eight hundred and ninety octovigintillion sescentillion, one hundred and twenty-three septemvigintillion sescentillion, four hundred and fifty-six sesvigintillion sescentillion, seven hundred and eighty-nine quinquavigintillion sescentillion, twelve quattuorvigintillion sescentillion, three hundred and forty-five tresvigintillion sescentillion, six hundred and seventy-eight duovigintillion sescentillion, nine hundred and one unvigintillion sescentillion, two hundred and thirty-four vigintillion sescentillion, five hundred and sixty-seven novendecillion sescentillion, eight hundred and ninety octodecillion sescentillion, one hundred and twenty-three septendecillion sescentillion, four hundred and fifty-six sedecillion sescentillion, seven hundred and eighty-nine quindecillion sescentillion, twelve quattuordecillion sescentillion, three hundred and forty-five tredecillion sescentillion, six hundred and seventy-eight duodecillion sescentillion, nine hundred and one undecillion sescentillion, two hundred and thirty-four decillion sescentillion, five hundred and sixty-seven nonillion sescentillion, eight hundred and ninety octillion sescentillion, one hundred and twenty-three septillion sescentillion, four hundred and fifty-six sextillion sescentillion, seven hundred and eighty-nine quintillion sescentillion, twelve quadrillion sescentillion, three hundred and forty-five trillion sescentillion, six hundred and seventy-eight billion sescentillion, nine hundred and one million sescentillion, two hundred and thirty-four thousand sescentillion, five hundred and sixty-seven sescentillion, eight hundred and ninety septillion nonagintillion quingentillion, one hundred and twenty-three sextillion nonagintillion quingentillion, four hundred and fifty-six quintillion nonagintillion quingentillion, seven hundred and eighty-nine quadrillion nonagintillion quingentillion, twelve trillion nonagintillion quingentillion, three hundred and forty-five billion nonagintillion quingentillion, six hundred and seventy-eight million nonagintillion quingentillion, nine hundred and one thousand nonagintillion quingentillion, two hundred and thirty-four nonagintillion quingentillion, five hundred and sixty-seven octillion octogintillion quingentillion, eight hundred and ninety septillion octogintillion quingentillion, one hundred and twenty-three sextillion octogintillion quingentillion, four hundred and fifty-six quintillion octogintillion quingentillion, seven hundred and eighty-nine quadrillion octogintillion quingentillion, twelve trillion octogintillion quingentillion, three hundred and forty-five billion octogintillion quingentillion, six hundred and seventy-eight million octogintillion quingentillion, nine hundred and one thousand octogintillion quingentillion, two hundred and thirty-four octogintillion quingentillion, five hundred and sixty-seven octillion septuagintillion quingentillion, eight hundred and ninety septillion septuagintillion quingentillion, one hundred and twenty-three sextillion septuagintillion quingentillion, four hundred and fifty-six quintillion septuagintillion quingentillion, seven hundred and eighty-nine quadrillion septuagintillion quingentillion, twelve trillion septuagintillion quingentillion, three hundred and forty-five billion septuagintillion quingentillion, six hundred and seventy-eight million septuagintillion quingentillion, nine hundred and one thousand septuagintillion quingentillion, two hundred and thirty-four septuagintillion quingentillion, five hundred and sixty-seven octillion sexagintillion quingentillion, eight hundred and ninety septillion sexagintillion quingentillion, one hundred and twenty-three sextillion sexagintillion quingentillion, four hundred and fifty-six quintillion sexagintillion quingentillion, seven hundred and eighty-nine quadrillion sexagintillion quingentillion, twelve trillion sexagintillion quingentillion, three hundred and forty-five billion sexagintillion quingentillion, six hundred and seventy-eight million sexagintillion quingentillion, nine hundred and one thousand sexagintillion quingentillion, two hundred and thirty-four sexagintillion quingentillion, five hundred and sixty-seven octillion quinquagintillion quingentillion, eight hundred and ninety septillion quinquagintillion quingentillion, one hundred and twenty-three sextillion quinquagintillion quingentillion, four hundred and fifty-six quintillion quinquagintillion quingentillion, seven hundred and eighty-nine quadrillion quinquagintillion quingentillion, twelve trillion quinquagintillion quingentillion, three hundred and forty-five billion quinquagintillion quingentillion, six hundred and seventy-eight million quinquagintillion quingentillion, nine hundred and one thousand quinquagintillion quingentillion, two hundred and thirty-four quinquagintillion quingentillion, five hundred and sixty-seven octillion quadragintillion quingentillion, eight hundred and ninety septillion quadragintillion quingentillion, one hundred and twenty-three sextillion quadragintillion quingentillion, four hundred and fifty-six quintillion quadragintillion quingentillion, seven hundred and eighty-nine quadrillion quadragintillion quingentillion, twelve trillion quadragintillion quingentillion, three hundred and forty-five billion quadragintillion quingentillion, six hundred and seventy-eight million quadragintillion quingentillion, nine hundred and one thousand quadragintillion quingentillion, two hundred and thirty-four quadragintillion quingentillion, five hundred and sixty-seven noventrigintillion quingentillion, eight hundred and ninety octotrigintillion quingentillion, one hundred and twenty-three septentrigintillion quingentillion, four hundred and fifty-six sestrigintillion quingentillion, seven hundred and eighty-nine quinquatrigintillion quingentillion, twelve quattuortrigintillion quingentillion, three hundred and forty-five trestrigintillion quingentillion, six hundred and seventy-eight duotrigintillion quingentillion, nine hundred and one untrigintillion quingentillion, two hundred and thirty-four trigintillion quingentillion, five hundred and sixty-seven novemvigintillion quingentillion, eight hundred and ninety octovigintillion quingentillion, one hundred and twenty-three septemvigintillion quingentillion, four hundred and fifty-six sesvigintillion quingentillion, seven hundred and eighty-nine quinquavigintillion quingentillion, twelve quattuorvigintillion quingentillion, three hundred and forty-five tresvigintillion quingentillion, six hundred and seventy-eight duovigintillion quingentillion, nine hundred and one unvigintillion quingentillion, two hundred and thirty-four vigintillion quingentillion, five hundred and sixty-seven novendecillion quingentillion, eight hundred and ninety octodecillion quingentillion, one hundred and twenty-three septendecillion quingentillion, four hundred and fifty-six sedecillion quingentillion, seven hundred and eighty-nine quindecillion quingentillion, twelve quattuordecillion quingentillion, three hundred and forty-five tredecillion quingentillion, six hundred and seventy-eight duodecillion quingentillion, nine hundred and one undecillion quingentillion, two hundred and thirty-four decillion quingentillion, five hundred and sixty-seven nonillion quingentillion, eight hundred and ninety octillion quingentillion, one hundred and twenty-three septillion quingentillion, four hundred and fifty-six sextillion quingentillion, seven hundred and eighty-nine quintillion quingentillion, twelve quadrillion quingentillion, three hundred and forty-five trillion quingentillion, six hundred and seventy-eight billion quingentillion, nine hundred and one million quingentillion, two hundred and thirty-four thousand quingentillion, five hundred and sixty-seven quingentillion, eight hundred and ninety septillion nonagintillion quadringentillion, one hundred and twenty-three sextillion nonagintillion quadringentillion, four hundred and fifty-six quintillion nonagintillion quadringentillion, seven hundred and eighty-nine quadrillion nonagintillion quadringentillion, twelve trillion nonagintillion quadringentillion, three hundred and forty-five billion nonagintillion quadringentillion, six hundred and seventy-eight million nonagintillion quadringentillion, nine hundred and one thousand nonagintillion quadringentillion, two hundred and thirty-four nonagintillion quadringentillion, five hundred and sixty-seven octillion octogintillion quadringentillion, eight hundred and ninety septillion octogintillion quadringentillion, one hundred and twenty-three sextillion octogintillion quadringentillion, four hundred and fifty-six quintillion octogintillion quadringentillion, seven hundred and eighty-nine quadrillion octogintillion quadringentillion, twelve trillion octogintillion quadringentillion, three hundred and forty-five billion octogintillion quadringentillion, six hundred and seventy-eight million octogintillion quadringentillion, nine hundred and one thousand octogintillion quadringentillion, two hundred and thirty-four octogintillion quadringentillion, five hundred and sixty-seven octillion septuagintillion quadringentillion, eight hundred and ninety septillion septuagintillion quadringentillion, one hundred and twenty-three sextillion septuagintillion quadringentillion, four hundred and fifty-six quintillion septuagintillion quadringentillion, seven hundred and eighty-nine quadrillion septuagintillion quadringentillion, twelve trillion septuagintillion quadringentillion, three hundred and forty-five billion septuagintillion quadringentillion, six hundred and seventy-eight million septuagintillion quadringentillion, nine hundred and one thousand septuagintillion quadringentillion, two hundred and thirty-four septuagintillion quadringentillion, five hundred and sixty-seven octillion sexagintillion quadringentillion, eight hundred and ninety septillion sexagintillion quadringentillion, one hundred and twenty-three sextillion sexagintillion quadringentillion, four hundred and fifty-six quintillion sexagintillion quadringentillion, seven hundred and eighty-nine quadrillion sexagintillion quadringentillion, twelve trillion sexagintillion quadringentillion, three hundred and forty-five billion sexagintillion quadringentillion, six hundred and seventy-eight million sexagintillion quadringentillion, nine hundred and one thousand sexagintillion quadringentillion, two hundred and thirty-four sexagintillion quadringentillion, five hundred and sixty-seven octillion quinquagintillion quadringentillion, eight hundred and ninety septillion quinquagintillion quadringentillion, one hundred and twenty-three sextillion quinquagintillion quadringentillion, four hundred and fifty-six quintillion quinquagintillion quadringentillion, seven hundred and eighty-nine quadrillion quinquagintillion quadringentillion, twelve trillion quinquagintillion quadringentillion, three hundred and forty-five billion quinquagintillion quadringentillion, six hundred and seventy-eight million quinquagintillion quadringentillion, nine hundred and one thousand quinquagintillion quadringentillion, two hundred and thirty-four quinquagintillion quadringentillion, five hundred and sixty-seven octillion quadragintillion quadringentillion, eight hundred and ninety septillion quadragintillion quadringentillion, one hundred and twenty-three sextillion quadragintillion quadringentillion, four hundred and fifty-six quintillion quadragintillion quadringentillion, seven hundred and eighty-nine quadrillion quadragintillion quadringentillion, twelve trillion quadragintillion quadringentillion, three hundred and forty-five billion quadragintillion quadringentillion, six hundred and seventy-eight million quadragintillion quadringentillion, nine hundred and one thousand quadragintillion quadringentillion, two hundred and thirty-four quadragintillion quadringentillion, five hundred and sixty-seven noventrigintillion quadringentillion, eight hundred and ninety octotrigintillion quadringentillion, one hundred and twenty-three septentrigintillion quadringentillion, four hundred and fifty-six sestrigintillion quadringentillion, seven hundred and eighty-nine quinquatrigintillion quadringentillion, twelve quattuortrigintillion quadringentillion, three hundred and forty-five trestrigintillion quadringentillion, six hundred and seventy-eight duotrigintillion quadringentillion, nine hundred and one untrigintillion quadringentillion, two hundred and thirty-four trigintillion quadringentillion, five hundred and sixty-seven novemvigintillion quadringentillion, eight hundred and ninety octovigintillion quadringentillion, one hundred and twenty-three septemvigintillion quadringentillion, four hundred and fifty-six sesvigintillion quadringentillion, seven hundred and eighty-nine quinquavigintillion quadringentillion, twelve quattuorvigintillion quadringentillion, three hundred and forty-five tresvigintillion quadringentillion, six hundred and seventy-eight duovigintillion quadringentillion, nine hundred and one unvigintillion quadringentillion, two hundred and thirty-four vigintillion quadringentillion, five hundred and sixty-seven novendecillion quadringentillion, eight hundred and ninety octodecillion quadringentillion, one hundred and twenty-three septendecillion quadringentillion, four hundred and fifty-six sedecillion quadringentillion, seven hundred and eighty-nine quindecillion quadringentillion, twelve quattuordecillion quadringentillion, three hundred and forty-five tredecillion quadringentillion, six hundred and seventy-eight duodecillion quadringentillion, nine hundred and one undecillion quadringentillion, two hundred and thirty-four decillion quadringentillion, five hundred and sixty-seven nonillion quadringentillion, eight hundred and ninety octillion quadringentillion, one hundred and twenty-three septillion quadringentillion, four hundred and fifty-six sextillion quadringentillion, seven hundred and eighty-nine quintillion quadringentillion, twelve quadrillion quadringentillion, three hundred and forty-five trillion quadringentillion, six hundred and seventy-eight billion quadringentillion, nine hundred and one million quadringentillion, two hundred and thirty-four thousand quadringentillion, five hundred and sixty-seven quadringentillion, eight hundred and ninety septillion nonagintillion trecentillion, one hundred and twenty-three sextillion nonagintillion trecentillion, four hundred and fifty-six quintillion nonagintillion trecentillion, seven hundred and eighty-nine quadrillion nonagintillion trecentillion, twelve trillion nonagintillion trecentillion, three hundred and forty-five billion nonagintillion trecentillion, six hundred and seventy-eight million nonagintillion trecentillion, nine hundred and one thousand nonagintillion trecentillion, two hundred and thirty-four nonagintillion trecentillion, five hundred and sixty-seven octillion octogintillion trecentillion, eight hundred and ninety septillion octogintillion trecentillion, one hundred and twenty-three sextillion octogintillion trecentillion, four hundred and fifty-six quintillion octogintillion trecentillion, seven hundred and eighty-nine quadrillion octogintillion trecentillion, twelve trillion octogintillion trecentillion, three hundred and forty-five billion octogintillion trecentillion, six hundred and seventy-eight million octogintillion trecentillion, nine hundred and one thousand octogintillion trecentillion, two hundred and thirty-four octogintillion trecentillion, five hundred and sixty-seven octillion septuagintillion trecentillion, eight hundred and ninety septillion septuagintillion trecentillion, one hundred and twenty-three sextillion septuagintillion trecentillion, four hundred and fifty-six quintillion septuagintillion trecentillion, seven hundred and eighty-nine quadrillion septuagintillion trecentillion, twelve trillion septuagintillion trecentillion, three hundred and forty-five billion septuagintillion trecentillion, six hundred and seventy-eight million septuagintillion trecentillion, nine hundred and one thousand septuagintillion trecentillion, two hundred and thirty-four septuagintillion trecentillion, five hundred and sixty-seven octillion sexagintillion trecentillion, eight hundred and ninety septillion sexagintillion trecentillion, one hundred and twenty-three sextillion sexagintillion trecentillion, four hundred and fifty-six quintillion sexagintillion trecentillion, seven hundred and eighty-nine quadrillion sexagintillion trecentillion, twelve trillion sexagintillion trecentillion, three hundred and forty-five billion sexagintillion trecentillion, six hundred and seventy-eight million sexagintillion trecentillion, nine hundred and one thousand sexagintillion trecentillion, two hundred and thirty-four sexagintillion trecentillion, five hundred and sixty-seven octillion quinquagintillion trecentillion, eight hundred and ninety septillion quinquagintillion trecentillion, one hundred and twenty-three sextillion quinquagintillion trecentillion, four hundred and fifty-six quintillion quinquagintillion trecentillion, seven hundred and eighty-nine quadrillion quinquagintillion trecentillion, twelve trillion quinquagintillion trecentillion, three hundred and forty-five billion quinquagintillion trecentillion, six hundred and seventy-eight million quinquagintillion trecentillion, nine hundred and one thousand quinquagintillion trecentillion, two hundred and thirty-four quinquagintillion trecentillion, five hundred and sixty-seven octillion quadragintillion trecentillion, eight hundred and ninety septillion quadragintillion trecentillion, one hundred and twenty-three sextillion quadragintillion trecentillion, four hundred and fifty-six quintillion quadragintillion trecentillion, seven hundred and eighty-nine quadrillion quadragintillion trecentillion, twelve trillion quadragintillion trecentillion, three hundred and forty-five billion quadragintillion trecentillion, six hundred and seventy-eight million quadragintillion trecentillion, nine hundred and one thousand quadragintillion trecentillion, two hundred and thirty-four quadragintillion trecentillion, five hundred and sixty-seven noventrigintillion trecentillion, eight hundred and ninety octotrigintillion trecentillion, one hundred and twenty-three septentrigintillion trecentillion, four hundred and fifty-six sestrigintillion trecentillion, seven hundred and eighty-nine quinquatrigintillion trecentillion, twelve quattuortrigintillion trecentillion, three hundred and forty-five trestrigintillion trecentillion, six hundred and seventy-eight duotrigintillion trecentillion, nine hundred and one untrigintillion trecentillion, two hundred and thirty-four trigintillion trecentillion, five hundred and sixty-seven novemvigintillion trecentillion, eight hundred and ninety octovigintillion trecentillion, one hundred and twenty-three septemvigintillion trecentillion, four hundred and fifty-six sesvigintillion trecentillion, seven hundred and eighty-nine quinquavigintillion trecentillion, twelve quattuorvigintillion trecentillion, three hundred and forty-five tresvigintillion trecentillion, six hundred and seventy-eight duovigintillion trecentillion, nine hundred and one unvigintillion trecentillion, two hundred and thirty-four vigintillion trecentillion, five hundred and sixty-seven novendecillion trecentillion, eight hundred and ninety octodecillion trecentillion, one hundred and twenty-three septendecillion trecentillion, four hundred and fifty-six sedecillion trecentillion, seven hundred and eighty-nine quindecillion trecentillion, twelve quattuordecillion trecentillion, three hundred and forty-five tredecillion trecentillion, six hundred and seventy-eight duodecillion trecentillion, nine hundred and one undecillion trecentillion, two hundred and thirty-four decillion trecentillion, five hundred and sixty-seven nonillion trecentillion, eight hundred and ninety octillion trecentillion, one hundred and twenty-three septillion trecentillion, four hundred and fifty-six sextillion trecentillion, seven hundred and eighty-nine quintillion trecentillion, twelve quadrillion trecentillion, three hundred and forty-five trillion trecentillion, six hundred and seventy-eight billion trecentillion, nine hundred and one million trecentillion, two hundred and thirty-four thousand trecentillion, five hundred and sixty-seven trecentillion, eight hundred and ninety septillion nonagintillion ducentillion, one hundred and twenty-three sextillion nonagintillion ducentillion, four hundred and fifty-six quintillion nonagintillion ducentillion, seven hundred and eighty-nine quadrillion nonagintillion ducentillion, twelve trillion nonagintillion ducentillion, three hundred and forty-five billion nonagintillion ducentillion, six hundred and seventy-eight million nonagintillion ducentillion, nine hundred and one thousand nonagintillion ducentillion, two hundred and thirty-four nonagintillion ducentillion, five hundred and sixty-seven octillion octogintillion ducentillion, eight hundred and ninety septillion octogintillion ducentillion, one hundred and twenty-three sextillion octogintillion ducentillion, four hundred and fifty-six quintillion octogintillion ducentillion, seven hundred and eighty-nine quadrillion octogintillion ducentillion, twelve trillion octogintillion ducentillion, three hundred and forty-five billion octogintillion ducentillion, six hundred and seventy-eight million octogintillion ducentillion, nine hundred and one thousand octogintillion ducentillion, two hundred and thirty-four octogintillion ducentillion, five hundred and sixty-seven octillion septuagintillion ducentillion, eight hundred and ninety septillion septuagintillion ducentillion, one hundred and twenty-three sextillion septuagintillion ducentillion, four hundred and fifty-six quintillion septuagintillion ducentillion, seven hundred and eighty-nine quadrillion septuagintillion ducentillion, twelve trillion septuagintillion ducentillion, three hundred and forty-five billion septuagintillion ducentillion, six hundred and seventy-eight million septuagintillion ducentillion, nine hundred and one thousand septuagintillion ducentillion, two hundred and thirty-four septuagintillion ducentillion, five hundred and sixty-seven octillion sexagintillion ducentillion, eight hundred and ninety septillion sexagintillion ducentillion, one hundred and twenty-three sextillion sexagintillion ducentillion, four hundred and fifty-six quintillion sexagintillion ducentillion, seven hundred and eighty-nine quadrillion sexagintillion ducentillion, twelve trillion sexagintillion ducentillion, three hundred and forty-five billion sexagintillion ducentillion, six hundred and seventy-eight million sexagintillion ducentillion, nine hundred and one thousand sexagintillion ducentillion, two hundred and thirty-four sexagintillion ducentillion, five hundred and sixty-seven octillion quinquagintillion ducentillion, eight hundred and ninety septillion quinquagintillion ducentillion, one hundred and twenty-three sextillion quinquagintillion ducentillion, four hundred and fifty-six quintillion quinquagintillion ducentillion, seven hundred and eighty-nine quadrillion quinquagintillion ducentillion, twelve trillion quinquagintillion ducentillion, three hundred and forty-five billion quinquagintillion ducentillion, six hundred and seventy-eight million quinquagintillion ducentillion, nine hundred and one thousand quinquagintillion ducentillion, two hundred and thirty-four quinquagintillion ducentillion, five hundred and sixty-seven octillion quadragintillion ducentillion, eight hundred and ninety septillion quadragintillion ducentillion, one hundred and twenty-three sextillion quadragintillion ducentillion, four hundred and fifty-six quintillion quadragintillion ducentillion, seven hundred and eighty-nine quadrillion quadragintillion ducentillion, twelve trillion quadragintillion ducentillion, three hundred and forty-five billion quadragintillion ducentillion, six hundred and seventy-eight million quadragintillion ducentillion, nine hundred and one thousand quadragintillion ducentillion, two hundred and thirty-four quadragintillion ducentillion, five hundred and sixty-seven noventrigintillion ducentillion, eight hundred and ninety octotrigintillion ducentillion, one hundred and twenty-three septentrigintillion ducentillion, four hundred and fifty-six sestrigintillion ducentillion, seven hundred and eighty-nine quinquatrigintillion ducentillion, twelve quattuortrigintillion ducentillion, three hundred and forty-five trestrigintillion ducentillion, six hundred and seventy-eight duotrigintillion ducentillion, nine hundred and one untrigintillion ducentillion, two hundred and thirty-four trigintillion ducentillion, five hundred and sixty-seven novemvigintillion ducentillion, eight hundred and ninety octovigintillion ducentillion, one hundred and twenty-three septemvigintillion ducentillion, four hundred and fifty-six sesvigintillion ducentillion, seven hundred and eighty-nine quinquavigintillion ducentillion, twelve quattuorvigintillion ducentillion, three hundred and forty-five tresvigintillion ducentillion, six hundred and seventy-eight duovigintillion ducentillion, nine hundred and one unvigintillion ducentillion, two hundred and thirty-four vigintillion ducentillion, five hundred and sixty-seven novendecillion ducentillion, eight hundred and ninety octodecillion ducentillion, one hundred and twenty-three septendecillion ducentillion, four hundred and fifty-six sedecillion ducentillion, seven hundred and eighty-nine quindecillion ducentillion, twelve quattuordecillion ducentillion, three hundred and forty-five tredecillion ducentillion, six hundred and seventy-eight duodecillion ducentillion, nine hundred and one undecillion ducentillion, two hundred and thirty-four decillion ducentillion, five hundred and sixty-seven nonillion ducentillion, eight hundred and ninety octillion ducentillion, one hundred and twenty-three septillion ducentillion, four hundred and fifty-six sextillion ducentillion, seven hundred and eighty-nine quintillion ducentillion, twelve quadrillion ducentillion, three hundred and forty-five trillion ducentillion, six hundred and seventy-eight billion ducentillion, nine hundred and one million ducentillion, two hundred and thirty-four thousand ducentillion, five hundred and sixty-seven ducentillion, eight hundred and ninety octillion nonagintacentillion, one hundred and twenty-three septillion nonagintacentillion, four hundred and fifty-six sextillion nonagintacentillion, seven hundred and eighty-nine quintillion nonagintacentillion, twelve quadrillion nonagintacentillion, three hundred and forty-five trillion nonagintacentillion, six hundred and seventy-eight billion nonagintacentillion, nine hundred and one million nonagintacentillion, two hundred and thirty-four thousand nonagintacentillion, five hundred and sixty-seven nonagintacentillion, eight hundred and ninety octillion octogintacentillion, one hundred and twenty-three septillion octogintacentillion, four hundred and fifty-six sextillion octogintacentillion, seven hundred and eighty-nine quintillion octogintacentillion, twelve quadrillion octogintacentillion, three hundred and forty-five trillion octogintacentillion, six hundred and seventy-eight billion octogintacentillion, nine hundred and one million octogintacentillion, two hundred and thirty-four thousand octogintacentillion, five hundred and sixty-seven octogintacentillion, eight hundred and ninety octillion septuagintacentillion, one hundred and twenty-three septillion septuagintacentillion, four hundred and fifty-six sextillion septuagintacentillion, seven hundred and eighty-nine quintillion septuagintacentillion, twelve quadrillion septuagintacentillion, three hundred and forty-five trillion septuagintacentillion, six hundred and seventy-eight billion septuagintacentillion, nine hundred and one million septuagintacentillion, two hundred and thirty-four thousand septuagintacentillion, five hundred and sixty-seven septuagintacentillion, eight hundred and ninety octillion sexagintacentillion, one hundred and twenty-three septillion sexagintacentillion, four hundred and fifty-six sextillion sexagintacentillion, seven hundred and eighty-nine quintillion sexagintacentillion, twelve quadrillion sexagintacentillion, three hundred and forty-five trillion sexagintacentillion, six hundred and seventy-eight billion sexagintacentillion, nine hundred and one million sexagintacentillion, two hundred and thirty-four thousand sexagintacentillion, five hundred and sixty-seven sexagintacentillion, eight hundred and ninety octillion quinquagintacentillion, one hundred and twenty-three septillion quinquagintacentillion, four hundred and fifty-six sextillion quinquagintacentillion, seven hundred and eighty-nine quintillion quinquagintacentillion, twelve quadrillion quinquagintacentillion, three hundred and forty-five trillion quinquagintacentillion, six hundred and seventy-eight billion quinquagintacentillion, nine hundred and one million quinquagintacentillion, two hundred and thirty-four thousand quinquagintacentillion, five hundred and sixty-seven quinquagintacentillion, eight hundred and ninety octillion quadragintacentillion, one hundred and twenty-three septillion quadragintacentillion, four hundred and fifty-six sextillion quadragintacentillion, seven hundred and eighty-nine quintillion quadragintacentillion, twelve quadrillion quadragintacentillion, three hundred and forty-five trillion quadragintacentillion, six hundred and seventy-eight billion quadragintacentillion, nine hundred and one million quadragintacentillion, two hundred and thirty-four thousand quadragintacentillion, five hundred and sixty-seven quadragintacentillion, eight hundred and ninety octillion trigintacentillion, one hundred and twenty-three septillion trigintacentillion, four hundred and fifty-six sextillion trigintacentillion, seven hundred and eighty-nine quintillion trigintacentillion, twelve quadrillion trigintacentillion, three hundred and forty-five trillion trigintacentillion, six hundred and seventy-eight billion trigintacentillion, nine hundred and one million trigintacentillion, two hundred and thirty-four thousand trigintacentillion, five hundred and sixty-seven trigintacentillion, eight hundred and ninety septillion unviginticentillion, one hundred and twenty-three sextillion unviginticentillion, four hundred and fifty-six quintillion unviginticentillion, seven hundred and eighty-nine quadrillion unviginticentillion, twelve trillion unviginticentillion, three hundred and forty-five billion unviginticentillion, six hundred and seventy-eight million unviginticentillion, nine hundred and one thousand unviginticentillion, two hundred and thirty-four unviginticentillion, five hundred and sixty-seven viginticentillion, eight hundred and ninety septillion undecicentillion, one hundred and twenty-three sextillion undecicentillion, four hundred and fifty-six quintillion undecicentillion, seven hundred and eighty-nine quadrillion undecicentillion, twelve trillion undecicentillion, three hundred and forty-five billion undecicentillion, six hundred and seventy-eight million undecicentillion, nine hundred and one thousand undecicentillion, two hundred and thirty-four undecicentillion, five hundred and sixty-seven decicentillion, eight hundred and ninety quintillion trescentillion, one hundred and twenty-three quadrillion trescentillion, four hundred and fifty-six trillion trescentillion, seven hundred and eighty-nine billion trescentillion, twelve million trescentillion, three hundred and forty-five thousand trescentillion, six hundred and seventy-eight trescentillion, nine hundred and one duocentillion, two hundred and thirty-four uncentillion, five hundred and sixty-seven centillion, eight hundred and ninety octillion nonagintillion, one hundred and twenty-three septillion nonagintillion, four hundred and fifty-six sextillion nonagintillion, seven hundred and eighty-nine quintillion nonagintillion, twelve quadrillion nonagintillion, three hundred and forty-five trillion nonagintillion, six hundred and seventy-eight billion nonagintillion, nine hundred and one million nonagintillion, two hundred and thirty-four thousand nonagintillion, five hundred and sixty-seven nonagintillion, eight hundred and ninety octillion octogintillion, one hundred and twenty-three septillion octogintillion, four hundred and fifty-six sextillion octogintillion, seven hundred and eighty-nine quintillion octogintillion, twelve quadrillion octogintillion, three hundred and forty-five trillion octogintillion, six hundred and seventy-eight billion octogintillion, nine hundred and one million octogintillion, two hundred and thirty-four thousand octogintillion, five hundred and sixty-seven octogintillion, eight hundred and ninety octillion septuagintillion, one hundred and twenty-three septillion septuagintillion, four hundred and fifty-six sextillion septuagintillion, seven hundred and eighty-nine quintillion septuagintillion, twelve quadrillion septuagintillion, three hundred and forty-five trillion septuagintillion, six hundred and seventy-eight billion septuagintillion, nine hundred and one million septuagintillion, two hundred and thirty-four thousand septuagintillion, five hundred and sixty-seven septuagintillion, eight hundred and ninety octillion sexagintillion, one hundred and twenty-three septillion sexagintillion, four hundred and fifty-six sextillion sexagintillion, seven hundred and eighty-nine quintillion sexagintillion, twelve quadrillion sexagintillion, three hundred and forty-five trillion sexagintillion, six hundred and seventy-eight billion sexagintillion, nine hundred and one million sexagintillion, two hundred and thirty-four thousand sexagintillion, five hundred and sixty-seven sexagintillion, eight hundred and ninety octillion quinquagintillion, one hundred and twenty-three septillion quinquagintillion, four hundred and fifty-six sextillion quinquagintillion, seven hundred and eighty-nine quintillion quinquagintillion, twelve quadrillion quinquagintillion, three hundred and forty-five trillion quinquagintillion, six hundred and seventy-eight billion quinquagintillion, nine hundred and one million quinquagintillion, two hundred and thirty-four thousand quinquagintillion, five hundred and sixty-seven quinquagintillion, eight hundred and ninety octillion quadragintillion, one hundred and twenty-three septillion quadragintillion, four hundred and fifty-six sextillion quadragintillion, seven hundred and eighty-nine quintillion quadragintillion, twelve quadrillion quadragintillion, three hundred and forty-five trillion quadragintillion, six hundred and seventy-eight billion quadragintillion, nine hundred and one million quadragintillion, two hundred and thirty-four thousand quadragintillion, five hundred and sixty-seven quadragintillion, eight hundred and ninety noventrigintillion, one hundred and twenty-three octotrigintillion, four hundred and fifty-six septentrigintillion, seven hundred and eighty-nine sestrigintillion, twelve quinquatrigintillion, three hundred and forty-five quattuortrigintillion, six hundred and seventy-eight trestrigintillion, nine hundred and one duotrigintillion, two hundred and thirty-four untrigintillion, five hundred and sixty-seven trigintillion, eight hundred and ninety novemvigintillion, one hundred and twenty-three octovigintillion, four hundred and fifty-six septemvigintillion, seven hundred and eighty-nine sesvigintillion, twelve quinquavigintillion, three hundred and forty-five quattuorvigintillion, six hundred and seventy-eight tresvigintillion, nine hundred and one duovigintillion, two hundred and thirty-four unvigintillion, five hundred and sixty-seven vigintillion, eight hundred and ninety novendecillion, one hundred and twenty-three octodecillion, four hundred and fifty-six septendecillion, seven hundred and eighty-nine sedecillion, twelve quindecillion, three hundred and forty-five quattuordecillion, six hundred and seventy-eight tredecillion, nine hundred and one duodecillion, two hundred and thirty-four undecillion, five hundred and sixty-seven decillion, eight hundred and ninety nonillion, one hundred and twenty-three octillion, four hundred and fifty-six septillion, seven hundred and eighty-nine sextillion, twelve quintillion, three hundred and forty-five quadrillion, six hundred and seventy-eight trillion, nine hundred and one billion, two hundred and thirty-four million, five hundred and sixty-seven thousand, eight hundred and ninety",
        ("one, two, three, four, five, six, seven, eight, nine, zero, " x 299) . "one, two, three, four, five, six, seven, eight, nine, zero",
        ("twelve, thirty-four, fifty-six, seventy-eight, ninety, " x 299 ) . "twelve, thirty-four, fifty-six, seventy-eight, ninety",
        ("one twenty-three, four fifty-six, seven eighty-nine, zero twelve, three forty-five, six seventy-eight, nine zero one, two thirty-four, five sixty-seven, eight ninety, " x 99) . "one twenty-three, four fifty-six, seven eighty-nine, zero twelve, three forty-five, six seventy-eight, nine zero one, two thirty-four, five sixty-seven, eight ninety",
        "one hundred and twenty-three sextillion nonagintillion nongentillion, four hundred and fifty-six quintillion nonagintillion nongentillion, seven hundred and eighty-nine quadrillion nonagintillion nongentillion, twelve trillion nonagintillion nongentillion, three hundred and forty-five billion nonagintillion nongentillion, six hundred and seventy-eight million nonagintillion nongentillion, nine hundred and one thousand nonagintillion nongentillion, two hundred and thirty-four nonagintillion nongentillion, five hundred and sixty-seven octillion octogintillion nongentillion, eight hundred and ninety septillion octogintillion nongentillion, one hundred and twenty-three sextillion octogintillion nongentillion, four hundred and fifty-six quintillion octogintillion nongentillion, seven hundred and eighty-nine quadrillion octogintillion nongentillion, twelve trillion octogintillion nongentillion, three hundred and forty-five billion octogintillion nongentillion, six hundred and seventy-eight million octogintillion nongentillion, nine hundred and one thousand octogintillion nongentillion, two hundred and thirty-four octogintillion nongentillion, five hundred and sixty-seven octillion septuagintillion nongentillion, eight hundred and ninety septillion septuagintillion nongentillion, one hundred and twenty-three sextillion septuagintillion nongentillion, four hundred and fifty-six quintillion septuagintillion nongentillion, seven hundred and eighty-nine quadrillion septuagintillion nongentillion, twelve trillion septuagintillion nongentillion, three hundred and forty-five billion septuagintillion nongentillion, six hundred and seventy-eight million septuagintillion nongentillion, nine hundred and one thousand septuagintillion nongentillion, two hundred and thirty-four septuagintillion nongentillion, five hundred and sixty-seven octillion sexagintillion nongentillion, eight hundred and ninety septillion sexagintillion nongentillion, one hundred and twenty-three sextillion sexagintillion nongentillion, four hundred and fifty-six quintillion sexagintillion nongentillion, seven hundred and eighty-nine quadrillion sexagintillion nongentillion, twelve trillion sexagintillion nongentillion, three hundred and forty-five billion sexagintillion nongentillion, six hundred and seventy-eight million sexagintillion nongentillion, nine hundred and one thousand sexagintillion nongentillion, two hundred and thirty-four sexagintillion nongentillion, five hundred and sixty-seven octillion quinquagintillion nongentillion, eight hundred and ninety septillion quinquagintillion nongentillion, one hundred and twenty-three sextillion quinquagintillion nongentillion, four hundred and fifty-six quintillion quinquagintillion nongentillion, seven hundred and eighty-nine quadrillion quinquagintillion nongentillion, twelve trillion quinquagintillion nongentillion, three hundred and forty-five billion quinquagintillion nongentillion, six hundred and seventy-eight million quinquagintillion nongentillion, nine hundred and one thousand quinquagintillion nongentillion, two hundred and thirty-four quinquagintillion nongentillion, five hundred and sixty-seven octillion quadragintillion nongentillion, eight hundred and ninety septillion quadragintillion nongentillion, one hundred and twenty-three sextillion quadragintillion nongentillion, four hundred and fifty-six quintillion quadragintillion nongentillion, seven hundred and eighty-nine quadrillion quadragintillion nongentillion, twelve trillion quadragintillion nongentillion, three hundred and forty-five billion quadragintillion nongentillion, six hundred and seventy-eight million quadragintillion nongentillion, nine hundred and one thousand quadragintillion nongentillion, two hundred and thirty-four quadragintillion nongentillion, five hundred and sixty-seven noventrigintillion nongentillion, eight hundred and ninety octotrigintillion nongentillion, one hundred and twenty-three septentrigintillion nongentillion, four hundred and fifty-six sestrigintillion nongentillion, seven hundred and eighty-nine quinquatrigintillion nongentillion, twelve quattuortrigintillion nongentillion, three hundred and forty-five trestrigintillion nongentillion, six hundred and seventy-eight duotrigintillion nongentillion, nine hundred and one untrigintillion nongentillion, two hundred and thirty-four trigintillion nongentillion, five hundred and sixty-seven novemvigintillion nongentillion, eight hundred and ninety octovigintillion nongentillion, one hundred and twenty-three septemvigintillion nongentillion, four hundred and fifty-six sesvigintillion nongentillion, seven hundred and eighty-nine quinquavigintillion nongentillion, twelve quattuorvigintillion nongentillion, three hundred and forty-five tresvigintillion nongentillion, six hundred and seventy-eight duovigintillion nongentillion, nine hundred and one unvigintillion nongentillion, two hundred and thirty-four vigintillion nongentillion, five hundred and sixty-seven novendecillion nongentillion, eight hundred and ninety octodecillion nongentillion, one hundred and twenty-three septendecillion nongentillion, four hundred and fifty-six sedecillion nongentillion, seven hundred and eighty-nine quindecillion nongentillion, twelve quattuordecillion nongentillion, three hundred and forty-five tredecillion nongentillion, six hundred and seventy-eight duodecillion nongentillion, nine hundred and one undecillion nongentillion, two hundred and thirty-four decillion nongentillion, five hundred and sixty-seven nonillion nongentillion, eight hundred and ninety octillion nongentillion, one hundred and twenty-three septillion nongentillion, four hundred and fifty-six sextillion nongentillion, seven hundred and eighty-nine quintillion nongentillion, twelve quadrillion nongentillion, three hundred and forty-five trillion nongentillion, six hundred and seventy-eight billion nongentillion, nine hundred and one million nongentillion, two hundred and thirty-four thousand nongentillion, five hundred and sixty-seven nongentillion, eight hundred and ninety septillion nonagintillion octingentillion, one hundred and twenty-three sextillion nonagintillion octingentillion, four hundred and fifty-six quintillion nonagintillion octingentillion, seven hundred and eighty-nine quadrillion nonagintillion octingentillion, twelve trillion nonagintillion octingentillion, three hundred and forty-five billion nonagintillion octingentillion, six hundred and seventy-eight million nonagintillion octingentillion, nine hundred and one thousand nonagintillion octingentillion, two hundred and thirty-four nonagintillion octingentillion, five hundred and sixty-seven octillion octogintillion octingentillion, eight hundred and ninety septillion octogintillion octingentillion, one hundred and twenty-three sextillion octogintillion octingentillion, four hundred and fifty-six quintillion octogintillion octingentillion, seven hundred and eighty-nine quadrillion octogintillion octingentillion, twelve trillion octogintillion octingentillion, three hundred and forty-five billion octogintillion octingentillion, six hundred and seventy-eight million octogintillion octingentillion, nine hundred and one thousand octogintillion octingentillion, two hundred and thirty-four octogintillion octingentillion, five hundred and sixty-seven octillion septuagintillion octingentillion, eight hundred and ninety septillion septuagintillion octingentillion, one hundred and twenty-three sextillion septuagintillion octingentillion, four hundred and fifty-six quintillion septuagintillion octingentillion, seven hundred and eighty-nine quadrillion septuagintillion octingentillion, twelve trillion septuagintillion octingentillion, three hundred and forty-five billion septuagintillion octingentillion, six hundred and seventy-eight million septuagintillion octingentillion, nine hundred and one thousand septuagintillion octingentillion, two hundred and thirty-four septuagintillion octingentillion, five hundred and sixty-seven octillion sexagintillion octingentillion, eight hundred and ninety septillion sexagintillion octingentillion, one hundred and twenty-three sextillion sexagintillion octingentillion, four hundred and fifty-six quintillion sexagintillion octingentillion, seven hundred and eighty-nine quadrillion sexagintillion octingentillion, twelve trillion sexagintillion octingentillion, three hundred and forty-five billion sexagintillion octingentillion, six hundred and seventy-eight million sexagintillion octingentillion, nine hundred and one thousand sexagintillion octingentillion, two hundred and thirty-four sexagintillion octingentillion, five hundred and sixty-seven octillion quinquagintillion octingentillion, eight hundred and ninety septillion quinquagintillion octingentillion, one hundred and twenty-three sextillion quinquagintillion octingentillion, four hundred and fifty-six quintillion quinquagintillion octingentillion, seven hundred and eighty-nine quadrillion quinquagintillion octingentillion, twelve trillion quinquagintillion octingentillion, three hundred and forty-five billion quinquagintillion octingentillion, six hundred and seventy-eight million quinquagintillion octingentillion, nine hundred and one thousand quinquagintillion octingentillion, two hundred and thirty-four quinquagintillion octingentillion, five hundred and sixty-seven octillion quadragintillion octingentillion, eight hundred and ninety septillion quadragintillion octingentillion, one hundred and twenty-three sextillion quadragintillion octingentillion, four hundred and fifty-six quintillion quadragintillion octingentillion, seven hundred and eighty-nine quadrillion quadragintillion octingentillion, twelve trillion quadragintillion octingentillion, three hundred and forty-five billion quadragintillion octingentillion, six hundred and seventy-eight million quadragintillion octingentillion, nine hundred and one thousand quadragintillion octingentillion, two hundred and thirty-four quadragintillion octingentillion, five hundred and sixty-seven noventrigintillion octingentillion, eight hundred and ninety octotrigintillion octingentillion, one hundred and twenty-three septentrigintillion octingentillion, four hundred and fifty-six sestrigintillion octingentillion, seven hundred and eighty-nine quinquatrigintillion octingentillion, twelve quattuortrigintillion octingentillion, three hundred and forty-five trestrigintillion octingentillion, six hundred and seventy-eight duotrigintillion octingentillion, nine hundred and one untrigintillion octingentillion, two hundred and thirty-four trigintillion octingentillion, five hundred and sixty-seven novemvigintillion octingentillion, eight hundred and ninety octovigintillion octingentillion, one hundred and twenty-three septemvigintillion octingentillion, four hundred and fifty-six sesvigintillion octingentillion, seven hundred and eighty-nine quinquavigintillion octingentillion, twelve quattuorvigintillion octingentillion, three hundred and forty-five tresvigintillion octingentillion, six hundred and seventy-eight duovigintillion octingentillion, nine hundred and one unvigintillion octingentillion, two hundred and thirty-four vigintillion octingentillion, five hundred and sixty-seven novendecillion octingentillion, eight hundred and ninety octodecillion octingentillion, one hundred and twenty-three septendecillion octingentillion, four hundred and fifty-six sedecillion octingentillion, seven hundred and eighty-nine quindecillion octingentillion, twelve quattuordecillion octingentillion, three hundred and forty-five tredecillion octingentillion, six hundred and seventy-eight duodecillion octingentillion, nine hundred and one undecillion octingentillion, two hundred and thirty-four decillion octingentillion, five hundred and sixty-seven nonillion octingentillion, eight hundred and ninety octillion octingentillion, one hundred and twenty-three septillion octingentillion, four hundred and fifty-six sextillion octingentillion, seven hundred and eighty-nine quintillion octingentillion, twelve quadrillion octingentillion, three hundred and forty-five trillion octingentillion, six hundred and seventy-eight billion octingentillion, nine hundred and one million octingentillion, two hundred and thirty-four thousand octingentillion, five hundred and sixty-seven octingentillion, eight hundred and ninety septillion nonagintillion septingentillion, one hundred and twenty-three sextillion nonagintillion septingentillion, four hundred and fifty-six quintillion nonagintillion septingentillion, seven hundred and eighty-nine quadrillion nonagintillion septingentillion, twelve trillion nonagintillion septingentillion, three hundred and forty-five billion nonagintillion septingentillion, six hundred and seventy-eight million nonagintillion septingentillion, nine hundred and one thousand nonagintillion septingentillion, two hundred and thirty-four nonagintillion septingentillion, five hundred and sixty-seven octillion octogintillion septingentillion, eight hundred and ninety septillion octogintillion septingentillion, one hundred and twenty-three sextillion octogintillion septingentillion, four hundred and fifty-six quintillion octogintillion septingentillion, seven hundred and eighty-nine quadrillion octogintillion septingentillion, twelve trillion octogintillion septingentillion, three hundred and forty-five billion octogintillion septingentillion, six hundred and seventy-eight million octogintillion septingentillion, nine hundred and one thousand octogintillion septingentillion, two hundred and thirty-four octogintillion septingentillion, five hundred and sixty-seven octillion septuagintillion septingentillion, eight hundred and ninety septillion septuagintillion septingentillion, one hundred and twenty-three sextillion septuagintillion septingentillion, four hundred and fifty-six quintillion septuagintillion septingentillion, seven hundred and eighty-nine quadrillion septuagintillion septingentillion, twelve trillion septuagintillion septingentillion, three hundred and forty-five billion septuagintillion septingentillion, six hundred and seventy-eight million septuagintillion septingentillion, nine hundred and one thousand septuagintillion septingentillion, two hundred and thirty-four septuagintillion septingentillion, five hundred and sixty-seven octillion sexagintillion septingentillion, eight hundred and ninety septillion sexagintillion septingentillion, one hundred and twenty-three sextillion sexagintillion septingentillion, four hundred and fifty-six quintillion sexagintillion septingentillion, seven hundred and eighty-nine quadrillion sexagintillion septingentillion, twelve trillion sexagintillion septingentillion, three hundred and forty-five billion sexagintillion septingentillion, six hundred and seventy-eight million sexagintillion septingentillion, nine hundred and one thousand sexagintillion septingentillion, two hundred and thirty-four sexagintillion septingentillion, five hundred and sixty-seven octillion quinquagintillion septingentillion, eight hundred and ninety septillion quinquagintillion septingentillion, one hundred and twenty-three sextillion quinquagintillion septingentillion, four hundred and fifty-six quintillion quinquagintillion septingentillion, seven hundred and eighty-nine quadrillion quinquagintillion septingentillion, twelve trillion quinquagintillion septingentillion, three hundred and forty-five billion quinquagintillion septingentillion, six hundred and seventy-eight million quinquagintillion septingentillion, nine hundred and one thousand quinquagintillion septingentillion, two hundred and thirty-four quinquagintillion septingentillion, five hundred and sixty-seven octillion quadragintillion septingentillion, eight hundred and ninety septillion quadragintillion septingentillion, one hundred and twenty-three sextillion quadragintillion septingentillion, four hundred and fifty-six quintillion quadragintillion septingentillion, seven hundred and eighty-nine quadrillion quadragintillion septingentillion, twelve trillion quadragintillion septingentillion, three hundred and forty-five billion quadragintillion septingentillion, six hundred and seventy-eight million quadragintillion septingentillion, nine hundred and one thousand quadragintillion septingentillion, two hundred and thirty-four quadragintillion septingentillion, five hundred and sixty-seven noventrigintillion septingentillion, eight hundred and ninety octotrigintillion septingentillion, one hundred and twenty-three septentrigintillion septingentillion, four hundred and fifty-six sestrigintillion septingentillion, seven hundred and eighty-nine quinquatrigintillion septingentillion, twelve quattuortrigintillion septingentillion, three hundred and forty-five trestrigintillion septingentillion, six hundred and seventy-eight duotrigintillion septingentillion, nine hundred and one untrigintillion septingentillion, two hundred and thirty-four trigintillion septingentillion, five hundred and sixty-seven novemvigintillion septingentillion, eight hundred and ninety octovigintillion septingentillion, one hundred and twenty-three septemvigintillion septingentillion, four hundred and fifty-six sesvigintillion septingentillion, seven hundred and eighty-nine quinquavigintillion septingentillion, twelve quattuorvigintillion septingentillion, three hundred and forty-five tresvigintillion septingentillion, six hundred and seventy-eight duovigintillion septingentillion, nine hundred and one unvigintillion septingentillion, two hundred and thirty-four vigintillion septingentillion, five hundred and sixty-seven novendecillion septingentillion, eight hundred and ninety octodecillion septingentillion, one hundred and twenty-three septendecillion septingentillion, four hundred and fifty-six sedecillion septingentillion, seven hundred and eighty-nine quindecillion septingentillion, twelve quattuordecillion septingentillion, three hundred and forty-five tredecillion septingentillion, six hundred and seventy-eight duodecillion septingentillion, nine hundred and one undecillion septingentillion, two hundred and thirty-four decillion septingentillion, five hundred and sixty-seven nonillion septingentillion, eight hundred and ninety octillion septingentillion, one hundred and twenty-three septillion septingentillion, four hundred and fifty-six sextillion septingentillion, seven hundred and eighty-nine quintillion septingentillion, twelve quadrillion septingentillion, three hundred and forty-five trillion septingentillion, six hundred and seventy-eight billion septingentillion, nine hundred and one million septingentillion, two hundred and thirty-four thousand septingentillion, five hundred and sixty-seven septingentillion, eight hundred and ninety septillion nonagintillion sescentillion, one hundred and twenty-three sextillion nonagintillion sescentillion, four hundred and fifty-six quintillion nonagintillion sescentillion, seven hundred and eighty-nine quadrillion nonagintillion sescentillion, twelve trillion nonagintillion sescentillion, three hundred and forty-five billion nonagintillion sescentillion, six hundred and seventy-eight million nonagintillion sescentillion, nine hundred and one thousand nonagintillion sescentillion, two hundred and thirty-four nonagintillion sescentillion, five hundred and sixty-seven octillion octogintillion sescentillion, eight hundred and ninety septillion octogintillion sescentillion, one hundred and twenty-three sextillion octogintillion sescentillion, four hundred and fifty-six quintillion octogintillion sescentillion, seven hundred and eighty-nine quadrillion octogintillion sescentillion, twelve trillion octogintillion sescentillion, three hundred and forty-five billion octogintillion sescentillion, six hundred and seventy-eight million octogintillion sescentillion, nine hundred and one thousand octogintillion sescentillion, two hundred and thirty-four octogintillion sescentillion, five hundred and sixty-seven octillion septuagintillion sescentillion, eight hundred and ninety septillion septuagintillion sescentillion, one hundred and twenty-three sextillion septuagintillion sescentillion, four hundred and fifty-six quintillion septuagintillion sescentillion, seven hundred and eighty-nine quadrillion septuagintillion sescentillion, twelve trillion septuagintillion sescentillion, three hundred and forty-five billion septuagintillion sescentillion, six hundred and seventy-eight million septuagintillion sescentillion, nine hundred and one thousand septuagintillion sescentillion, two hundred and thirty-four septuagintillion sescentillion, five hundred and sixty-seven octillion sexagintillion sescentillion, eight hundred and ninety septillion sexagintillion sescentillion, one hundred and twenty-three sextillion sexagintillion sescentillion, four hundred and fifty-six quintillion sexagintillion sescentillion, seven hundred and eighty-nine quadrillion sexagintillion sescentillion, twelve trillion sexagintillion sescentillion, three hundred and forty-five billion sexagintillion sescentillion, six hundred and seventy-eight million sexagintillion sescentillion, nine hundred and one thousand sexagintillion sescentillion, two hundred and thirty-four sexagintillion sescentillion, five hundred and sixty-seven octillion quinquagintillion sescentillion, eight hundred and ninety septillion quinquagintillion sescentillion, one hundred and twenty-three sextillion quinquagintillion sescentillion, four hundred and fifty-six quintillion quinquagintillion sescentillion, seven hundred and eighty-nine quadrillion quinquagintillion sescentillion, twelve trillion quinquagintillion sescentillion, three hundred and forty-five billion quinquagintillion sescentillion, six hundred and seventy-eight million quinquagintillion sescentillion, nine hundred and one thousand quinquagintillion sescentillion, two hundred and thirty-four quinquagintillion sescentillion, five hundred and sixty-seven octillion quadragintillion sescentillion, eight hundred and ninety septillion quadragintillion sescentillion, one hundred and twenty-three sextillion quadragintillion sescentillion, four hundred and fifty-six quintillion quadragintillion sescentillion, seven hundred and eighty-nine quadrillion quadragintillion sescentillion, twelve trillion quadragintillion sescentillion, three hundred and forty-five billion quadragintillion sescentillion, six hundred and seventy-eight million quadragintillion sescentillion, nine hundred and one thousand quadragintillion sescentillion, two hundred and thirty-four quadragintillion sescentillion, five hundred and sixty-seven noventrigintillion sescentillion, eight hundred and ninety octotrigintillion sescentillion, one hundred and twenty-three septentrigintillion sescentillion, four hundred and fifty-six sestrigintillion sescentillion, seven hundred and eighty-nine quinquatrigintillion sescentillion, twelve quattuortrigintillion sescentillion, three hundred and forty-five trestrigintillion sescentillion, six hundred and seventy-eight duotrigintillion sescentillion, nine hundred and one untrigintillion sescentillion, two hundred and thirty-four trigintillion sescentillion, five hundred and sixty-seven novemvigintillion sescentillion, eight hundred and ninety octovigintillion sescentillion, one hundred and twenty-three septemvigintillion sescentillion, four hundred and fifty-six sesvigintillion sescentillion, seven hundred and eighty-nine quinquavigintillion sescentillion, twelve quattuorvigintillion sescentillion, three hundred and forty-five tresvigintillion sescentillion, six hundred and seventy-eight duovigintillion sescentillion, nine hundred and one unvigintillion sescentillion, two hundred and thirty-four vigintillion sescentillion, five hundred and sixty-seven novendecillion sescentillion, eight hundred and ninety octodecillion sescentillion, one hundred and twenty-three septendecillion sescentillion, four hundred and fifty-six sedecillion sescentillion, seven hundred and eighty-nine quindecillion sescentillion, twelve quattuordecillion sescentillion, three hundred and forty-five tredecillion sescentillion, six hundred and seventy-eight duodecillion sescentillion, nine hundred and one undecillion sescentillion, two hundred and thirty-four decillion sescentillion, five hundred and sixty-seven nonillion sescentillion, eight hundred and ninety octillion sescentillion, one hundred and twenty-three septillion sescentillion, four hundred and fifty-six sextillion sescentillion, seven hundred and eighty-nine quintillion sescentillion, twelve quadrillion sescentillion, three hundred and forty-five trillion sescentillion, six hundred and seventy-eight billion sescentillion, nine hundred and one million sescentillion, two hundred and thirty-four thousand sescentillion, five hundred and sixty-seven sescentillion, eight hundred and ninety septillion nonagintillion quingentillion, one hundred and twenty-three sextillion nonagintillion quingentillion, four hundred and fifty-six quintillion nonagintillion quingentillion, seven hundred and eighty-nine quadrillion nonagintillion quingentillion, twelve trillion nonagintillion quingentillion, three hundred and forty-five billion nonagintillion quingentillion, six hundred and seventy-eight million nonagintillion quingentillion, nine hundred and one thousand nonagintillion quingentillion, two hundred and thirty-four nonagintillion quingentillion, five hundred and sixty-seven octillion octogintillion quingentillion, eight hundred and ninety septillion octogintillion quingentillion, one hundred and twenty-three sextillion octogintillion quingentillion, four hundred and fifty-six quintillion octogintillion quingentillion, seven hundred and eighty-nine quadrillion octogintillion quingentillion, twelve trillion octogintillion quingentillion, three hundred and forty-five billion octogintillion quingentillion, six hundred and seventy-eight million octogintillion quingentillion, nine hundred and one thousand octogintillion quingentillion, two hundred and thirty-four octogintillion quingentillion, five hundred and sixty-seven octillion septuagintillion quingentillion, eight hundred and ninety septillion septuagintillion quingentillion, one hundred and twenty-three sextillion septuagintillion quingentillion, four hundred and fifty-six quintillion septuagintillion quingentillion, seven hundred and eighty-nine quadrillion septuagintillion quingentillion, twelve trillion septuagintillion quingentillion, three hundred and forty-five billion septuagintillion quingentillion, six hundred and seventy-eight million septuagintillion quingentillion, nine hundred and one thousand septuagintillion quingentillion, two hundred and thirty-four septuagintillion quingentillion, five hundred and sixty-seven octillion sexagintillion quingentillion, eight hundred and ninety septillion sexagintillion quingentillion, one hundred and twenty-three sextillion sexagintillion quingentillion, four hundred and fifty-six quintillion sexagintillion quingentillion, seven hundred and eighty-nine quadrillion sexagintillion quingentillion, twelve trillion sexagintillion quingentillion, three hundred and forty-five billion sexagintillion quingentillion, six hundred and seventy-eight million sexagintillion quingentillion, nine hundred and one thousand sexagintillion quingentillion, two hundred and thirty-four sexagintillion quingentillion, five hundred and sixty-seven octillion quinquagintillion quingentillion, eight hundred and ninety septillion quinquagintillion quingentillion, one hundred and twenty-three sextillion quinquagintillion quingentillion, four hundred and fifty-six quintillion quinquagintillion quingentillion, seven hundred and eighty-nine quadrillion quinquagintillion quingentillion, twelve trillion quinquagintillion quingentillion, three hundred and forty-five billion quinquagintillion quingentillion, six hundred and seventy-eight million quinquagintillion quingentillion, nine hundred and one thousand quinquagintillion quingentillion, two hundred and thirty-four quinquagintillion quingentillion, five hundred and sixty-seven octillion quadragintillion quingentillion, eight hundred and ninety septillion quadragintillion quingentillion, one hundred and twenty-three sextillion quadragintillion quingentillion, four hundred and fifty-six quintillion quadragintillion quingentillion, seven hundred and eighty-nine quadrillion quadragintillion quingentillion, twelve trillion quadragintillion quingentillion, three hundred and forty-five billion quadragintillion quingentillion, six hundred and seventy-eight million quadragintillion quingentillion, nine hundred and one thousand quadragintillion quingentillion, two hundred and thirty-four quadragintillion quingentillion, five hundred and sixty-seven noventrigintillion quingentillion, eight hundred and ninety octotrigintillion quingentillion, one hundred and twenty-three septentrigintillion quingentillion, four hundred and fifty-six sestrigintillion quingentillion, seven hundred and eighty-nine quinquatrigintillion quingentillion, twelve quattuortrigintillion quingentillion, three hundred and forty-five trestrigintillion quingentillion, six hundred and seventy-eight duotrigintillion quingentillion, nine hundred and one untrigintillion quingentillion, two hundred and thirty-four trigintillion quingentillion, five hundred and sixty-seven novemvigintillion quingentillion, eight hundred and ninety octovigintillion quingentillion, one hundred and twenty-three septemvigintillion quingentillion, four hundred and fifty-six sesvigintillion quingentillion, seven hundred and eighty-nine quinquavigintillion quingentillion, twelve quattuorvigintillion quingentillion, three hundred and forty-five tresvigintillion quingentillion, six hundred and seventy-eight duovigintillion quingentillion, nine hundred and one unvigintillion quingentillion, two hundred and thirty-four vigintillion quingentillion, five hundred and sixty-seven novendecillion quingentillion, eight hundred and ninety octodecillion quingentillion, one hundred and twenty-three septendecillion quingentillion, four hundred and fifty-six sedecillion quingentillion, seven hundred and eighty-nine quindecillion quingentillion, twelve quattuordecillion quingentillion, three hundred and forty-five tredecillion quingentillion, six hundred and seventy-eight duodecillion quingentillion, nine hundred and one undecillion quingentillion, two hundred and thirty-four decillion quingentillion, five hundred and sixty-seven nonillion quingentillion, eight hundred and ninety octillion quingentillion, one hundred and twenty-three septillion quingentillion, four hundred and fifty-six sextillion quingentillion, seven hundred and eighty-nine quintillion quingentillion, twelve quadrillion quingentillion, three hundred and forty-five trillion quingentillion, six hundred and seventy-eight billion quingentillion, nine hundred and one million quingentillion, two hundred and thirty-four thousand quingentillion, five hundred and sixty-seven quingentillion, eight hundred and ninety septillion nonagintillion quadringentillion, one hundred and twenty-three sextillion nonagintillion quadringentillion, four hundred and fifty-six quintillion nonagintillion quadringentillion, seven hundred and eighty-nine quadrillion nonagintillion quadringentillion, twelve trillion nonagintillion quadringentillion, three hundred and forty-five billion nonagintillion quadringentillion, six hundred and seventy-eight million nonagintillion quadringentillion, nine hundred and one thousand nonagintillion quadringentillion, two hundred and thirty-four nonagintillion quadringentillion, five hundred and sixty-seven octillion octogintillion quadringentillion, eight hundred and ninety septillion octogintillion quadringentillion, one hundred and twenty-three sextillion octogintillion quadringentillion, four hundred and fifty-six quintillion octogintillion quadringentillion, seven hundred and eighty-nine quadrillion octogintillion quadringentillion, twelve trillion octogintillion quadringentillion, three hundred and forty-five billion octogintillion quadringentillion, six hundred and seventy-eight million octogintillion quadringentillion, nine hundred and one thousand octogintillion quadringentillion, two hundred and thirty-four octogintillion quadringentillion, five hundred and sixty-seven octillion septuagintillion quadringentillion, eight hundred and ninety septillion septuagintillion quadringentillion, one hundred and twenty-three sextillion septuagintillion quadringentillion, four hundred and fifty-six quintillion septuagintillion quadringentillion, seven hundred and eighty-nine quadrillion septuagintillion quadringentillion, twelve trillion septuagintillion quadringentillion, three hundred and forty-five billion septuagintillion quadringentillion, six hundred and seventy-eight million septuagintillion quadringentillion, nine hundred and one thousand septuagintillion quadringentillion, two hundred and thirty-four septuagintillion quadringentillion, five hundred and sixty-seven octillion sexagintillion quadringentillion, eight hundred and ninety septillion sexagintillion quadringentillion, one hundred and twenty-three sextillion sexagintillion quadringentillion, four hundred and fifty-six quintillion sexagintillion quadringentillion, seven hundred and eighty-nine quadrillion sexagintillion quadringentillion, twelve trillion sexagintillion quadringentillion, three hundred and forty-five billion sexagintillion quadringentillion, six hundred and seventy-eight million sexagintillion quadringentillion, nine hundred and one thousand sexagintillion quadringentillion, two hundred and thirty-four sexagintillion quadringentillion, five hundred and sixty-seven octillion quinquagintillion quadringentillion, eight hundred and ninety septillion quinquagintillion quadringentillion, one hundred and twenty-three sextillion quinquagintillion quadringentillion, four hundred and fifty-six quintillion quinquagintillion quadringentillion, seven hundred and eighty-nine quadrillion quinquagintillion quadringentillion, twelve trillion quinquagintillion quadringentillion, three hundred and forty-five billion quinquagintillion quadringentillion, six hundred and seventy-eight million quinquagintillion quadringentillion, nine hundred and one thousand quinquagintillion quadringentillion, two hundred and thirty-four quinquagintillion quadringentillion, five hundred and sixty-seven octillion quadragintillion quadringentillion, eight hundred and ninety septillion quadragintillion quadringentillion, one hundred and twenty-three sextillion quadragintillion quadringentillion, four hundred and fifty-six quintillion quadragintillion quadringentillion, seven hundred and eighty-nine quadrillion quadragintillion quadringentillion, twelve trillion quadragintillion quadringentillion, three hundred and forty-five billion quadragintillion quadringentillion, six hundred and seventy-eight million quadragintillion quadringentillion, nine hundred and one thousand quadragintillion quadringentillion, two hundred and thirty-four quadragintillion quadringentillion, five hundred and sixty-seven noventrigintillion quadringentillion, eight hundred and ninety octotrigintillion quadringentillion, one hundred and twenty-three septentrigintillion quadringentillion, four hundred and fifty-six sestrigintillion quadringentillion, seven hundred and eighty-nine quinquatrigintillion quadringentillion, twelve quattuortrigintillion quadringentillion, three hundred and forty-five trestrigintillion quadringentillion, six hundred and seventy-eight duotrigintillion quadringentillion, nine hundred and one untrigintillion quadringentillion, two hundred and thirty-four trigintillion quadringentillion, five hundred and sixty-seven novemvigintillion quadringentillion, eight hundred and ninety octovigintillion quadringentillion, one hundred and twenty-three septemvigintillion quadringentillion, four hundred and fifty-six sesvigintillion quadringentillion, seven hundred and eighty-nine quinquavigintillion quadringentillion, twelve quattuorvigintillion quadringentillion, three hundred and forty-five tresvigintillion quadringentillion, six hundred and seventy-eight duovigintillion quadringentillion, nine hundred and one unvigintillion quadringentillion, two hundred and thirty-four vigintillion quadringentillion, five hundred and sixty-seven novendecillion quadringentillion, eight hundred and ninety octodecillion quadringentillion, one hundred and twenty-three septendecillion quadringentillion, four hundred and fifty-six sedecillion quadringentillion, seven hundred and eighty-nine quindecillion quadringentillion, twelve quattuordecillion quadringentillion, three hundred and forty-five tredecillion quadringentillion, six hundred and seventy-eight duodecillion quadringentillion, nine hundred and one undecillion quadringentillion, two hundred and thirty-four decillion quadringentillion, five hundred and sixty-seven nonillion quadringentillion, eight hundred and ninety octillion quadringentillion, one hundred and twenty-three septillion quadringentillion, four hundred and fifty-six sextillion quadringentillion, seven hundred and eighty-nine quintillion quadringentillion, twelve quadrillion quadringentillion, three hundred and forty-five trillion quadringentillion, six hundred and seventy-eight billion quadringentillion, nine hundred and one million quadringentillion, two hundred and thirty-four thousand quadringentillion, five hundred and sixty-seven quadringentillion, eight hundred and ninety septillion nonagintillion trecentillion, one hundred and twenty-three sextillion nonagintillion trecentillion, four hundred and fifty-six quintillion nonagintillion trecentillion, seven hundred and eighty-nine quadrillion nonagintillion trecentillion, twelve trillion nonagintillion trecentillion, three hundred and forty-five billion nonagintillion trecentillion, six hundred and seventy-eight million nonagintillion trecentillion, nine hundred and one thousand nonagintillion trecentillion, two hundred and thirty-four nonagintillion trecentillion, five hundred and sixty-seven octillion octogintillion trecentillion, eight hundred and ninety septillion octogintillion trecentillion, one hundred and twenty-three sextillion octogintillion trecentillion, four hundred and fifty-six quintillion octogintillion trecentillion, seven hundred and eighty-nine quadrillion octogintillion trecentillion, twelve trillion octogintillion trecentillion, three hundred and forty-five billion octogintillion trecentillion, six hundred and seventy-eight million octogintillion trecentillion, nine hundred and one thousand octogintillion trecentillion, two hundred and thirty-four octogintillion trecentillion, five hundred and sixty-seven octillion septuagintillion trecentillion, eight hundred and ninety septillion septuagintillion trecentillion, one hundred and twenty-three sextillion septuagintillion trecentillion, four hundred and fifty-six quintillion septuagintillion trecentillion, seven hundred and eighty-nine quadrillion septuagintillion trecentillion, twelve trillion septuagintillion trecentillion, three hundred and forty-five billion septuagintillion trecentillion, six hundred and seventy-eight million septuagintillion trecentillion, nine hundred and one thousand septuagintillion trecentillion, two hundred and thirty-four septuagintillion trecentillion, five hundred and sixty-seven octillion sexagintillion trecentillion, eight hundred and ninety septillion sexagintillion trecentillion, one hundred and twenty-three sextillion sexagintillion trecentillion, four hundred and fifty-six quintillion sexagintillion trecentillion, seven hundred and eighty-nine quadrillion sexagintillion trecentillion, twelve trillion sexagintillion trecentillion, three hundred and forty-five billion sexagintillion trecentillion, six hundred and seventy-eight million sexagintillion trecentillion, nine hundred and one thousand sexagintillion trecentillion, two hundred and thirty-four sexagintillion trecentillion, five hundred and sixty-seven octillion quinquagintillion trecentillion, eight hundred and ninety septillion quinquagintillion trecentillion, one hundred and twenty-three sextillion quinquagintillion trecentillion, four hundred and fifty-six quintillion quinquagintillion trecentillion, seven hundred and eighty-nine quadrillion quinquagintillion trecentillion, twelve trillion quinquagintillion trecentillion, three hundred and forty-five billion quinquagintillion trecentillion, six hundred and seventy-eight million quinquagintillion trecentillion, nine hundred and one thousand quinquagintillion trecentillion, two hundred and thirty-four quinquagintillion trecentillion, five hundred and sixty-seven octillion quadragintillion trecentillion, eight hundred and ninety septillion quadragintillion trecentillion, one hundred and twenty-three sextillion quadragintillion trecentillion, four hundred and fifty-six quintillion quadragintillion trecentillion, seven hundred and eighty-nine quadrillion quadragintillion trecentillion, twelve trillion quadragintillion trecentillion, three hundred and forty-five billion quadragintillion trecentillion, six hundred and seventy-eight million quadragintillion trecentillion, nine hundred and one thousand quadragintillion trecentillion, two hundred and thirty-four quadragintillion trecentillion, five hundred and sixty-seven noventrigintillion trecentillion, eight hundred and ninety octotrigintillion trecentillion, one hundred and twenty-three septentrigintillion trecentillion, four hundred and fifty-six sestrigintillion trecentillion, seven hundred and eighty-nine quinquatrigintillion trecentillion, twelve quattuortrigintillion trecentillion, three hundred and forty-five trestrigintillion trecentillion, six hundred and seventy-eight duotrigintillion trecentillion, nine hundred and one untrigintillion trecentillion, two hundred and thirty-four trigintillion trecentillion, five hundred and sixty-seven novemvigintillion trecentillion, eight hundred and ninety octovigintillion trecentillion, one hundred and twenty-three septemvigintillion trecentillion, four hundred and fifty-six sesvigintillion trecentillion, seven hundred and eighty-nine quinquavigintillion trecentillion, twelve quattuorvigintillion trecentillion, three hundred and forty-five tresvigintillion trecentillion, six hundred and seventy-eight duovigintillion trecentillion, nine hundred and one unvigintillion trecentillion, two hundred and thirty-four vigintillion trecentillion, five hundred and sixty-seven novendecillion trecentillion, eight hundred and ninety octodecillion trecentillion, one hundred and twenty-three septendecillion trecentillion, four hundred and fifty-six sedecillion trecentillion, seven hundred and eighty-nine quindecillion trecentillion, twelve quattuordecillion trecentillion, three hundred and forty-five tredecillion trecentillion, six hundred and seventy-eight duodecillion trecentillion, nine hundred and one undecillion trecentillion, two hundred and thirty-four decillion trecentillion, five hundred and sixty-seven nonillion trecentillion, eight hundred and ninety octillion trecentillion, one hundred and twenty-three septillion trecentillion, four hundred and fifty-six sextillion trecentillion, seven hundred and eighty-nine quintillion trecentillion, twelve quadrillion trecentillion, three hundred and forty-five trillion trecentillion, six hundred and seventy-eight billion trecentillion, nine hundred and one million trecentillion, two hundred and thirty-four thousand trecentillion, five hundred and sixty-seven trecentillion, eight hundred and ninety septillion nonagintillion ducentillion, one hundred and twenty-three sextillion nonagintillion ducentillion, four hundred and fifty-six quintillion nonagintillion ducentillion, seven hundred and eighty-nine quadrillion nonagintillion ducentillion, twelve trillion nonagintillion ducentillion, three hundred and forty-five billion nonagintillion ducentillion, six hundred and seventy-eight million nonagintillion ducentillion, nine hundred and one thousand nonagintillion ducentillion, two hundred and thirty-four nonagintillion ducentillion, five hundred and sixty-seven octillion octogintillion ducentillion, eight hundred and ninety septillion octogintillion ducentillion, one hundred and twenty-three sextillion octogintillion ducentillion, four hundred and fifty-six quintillion octogintillion ducentillion, seven hundred and eighty-nine quadrillion octogintillion ducentillion, twelve trillion octogintillion ducentillion, three hundred and forty-five billion octogintillion ducentillion, six hundred and seventy-eight million octogintillion ducentillion, nine hundred and one thousand octogintillion ducentillion, two hundred and thirty-four octogintillion ducentillion, five hundred and sixty-seven octillion septuagintillion ducentillion, eight hundred and ninety septillion septuagintillion ducentillion, one hundred and twenty-three sextillion septuagintillion ducentillion, four hundred and fifty-six quintillion septuagintillion ducentillion, seven hundred and eighty-nine quadrillion septuagintillion ducentillion, twelve trillion septuagintillion ducentillion, three hundred and forty-five billion septuagintillion ducentillion, six hundred and seventy-eight million septuagintillion ducentillion, nine hundred and one thousand septuagintillion ducentillion, two hundred and thirty-four septuagintillion ducentillion, five hundred and sixty-seven octillion sexagintillion ducentillion, eight hundred and ninety septillion sexagintillion ducentillion, one hundred and twenty-three sextillion sexagintillion ducentillion, four hundred and fifty-six quintillion sexagintillion ducentillion, seven hundred and eighty-nine quadrillion sexagintillion ducentillion, twelve trillion sexagintillion ducentillion, three hundred and forty-five billion sexagintillion ducentillion, six hundred and seventy-eight million sexagintillion ducentillion, nine hundred and one thousand sexagintillion ducentillion, two hundred and thirty-four sexagintillion ducentillion, five hundred and sixty-seven octillion quinquagintillion ducentillion, eight hundred and ninety septillion quinquagintillion ducentillion, one hundred and twenty-three sextillion quinquagintillion ducentillion, four hundred and fifty-six quintillion quinquagintillion ducentillion, seven hundred and eighty-nine quadrillion quinquagintillion ducentillion, twelve trillion quinquagintillion ducentillion, three hundred and forty-five billion quinquagintillion ducentillion, six hundred and seventy-eight million quinquagintillion ducentillion, nine hundred and one thousand quinquagintillion ducentillion, two hundred and thirty-four quinquagintillion ducentillion, five hundred and sixty-seven octillion quadragintillion ducentillion, eight hundred and ninety septillion quadragintillion ducentillion, one hundred and twenty-three sextillion quadragintillion ducentillion, four hundred and fifty-six quintillion quadragintillion ducentillion, seven hundred and eighty-nine quadrillion quadragintillion ducentillion, twelve trillion quadragintillion ducentillion, three hundred and forty-five billion quadragintillion ducentillion, six hundred and seventy-eight million quadragintillion ducentillion, nine hundred and one thousand quadragintillion ducentillion, two hundred and thirty-four quadragintillion ducentillion, five hundred and sixty-seven noventrigintillion ducentillion, eight hundred and ninety octotrigintillion ducentillion, one hundred and twenty-three septentrigintillion ducentillion, four hundred and fifty-six sestrigintillion ducentillion, seven hundred and eighty-nine quinquatrigintillion ducentillion, twelve quattuortrigintillion ducentillion, three hundred and forty-five trestrigintillion ducentillion, six hundred and seventy-eight duotrigintillion ducentillion, nine hundred and one untrigintillion ducentillion, two hundred and thirty-four trigintillion ducentillion, five hundred and sixty-seven novemvigintillion ducentillion, eight hundred and ninety octovigintillion ducentillion, one hundred and twenty-three septemvigintillion ducentillion, four hundred and fifty-six sesvigintillion ducentillion, seven hundred and eighty-nine quinquavigintillion ducentillion, twelve quattuorvigintillion ducentillion, three hundred and forty-five tresvigintillion ducentillion, six hundred and seventy-eight duovigintillion ducentillion, nine hundred and one unvigintillion ducentillion, two hundred and thirty-four vigintillion ducentillion, five hundred and sixty-seven novendecillion ducentillion, eight hundred and ninety octodecillion ducentillion, one hundred and twenty-three septendecillion ducentillion, four hundred and fifty-six sedecillion ducentillion, seven hundred and eighty-nine quindecillion ducentillion, twelve quattuordecillion ducentillion, three hundred and forty-five tredecillion ducentillion, six hundred and seventy-eight duodecillion ducentillion, nine hundred and one undecillion ducentillion, two hundred and thirty-four decillion ducentillion, five hundred and sixty-seven nonillion ducentillion, eight hundred and ninety octillion ducentillion, one hundred and twenty-three septillion ducentillion, four hundred and fifty-six sextillion ducentillion, seven hundred and eighty-nine quintillion ducentillion, twelve quadrillion ducentillion, three hundred and forty-five trillion ducentillion, six hundred and seventy-eight billion ducentillion, nine hundred and one million ducentillion, two hundred and thirty-four thousand ducentillion, five hundred and sixty-seven ducentillion, eight hundred and ninety octillion nonagintacentillion, one hundred and twenty-three septillion nonagintacentillion, four hundred and fifty-six sextillion nonagintacentillion, seven hundred and eighty-nine quintillion nonagintacentillion, twelve quadrillion nonagintacentillion, three hundred and forty-five trillion nonagintacentillion, six hundred and seventy-eight billion nonagintacentillion, nine hundred and one million nonagintacentillion, two hundred and thirty-four thousand nonagintacentillion, five hundred and sixty-seven nonagintacentillion, eight hundred and ninety octillion octogintacentillion, one hundred and twenty-three septillion octogintacentillion, four hundred and fifty-six sextillion octogintacentillion, seven hundred and eighty-nine quintillion octogintacentillion, twelve quadrillion octogintacentillion, three hundred and forty-five trillion octogintacentillion, six hundred and seventy-eight billion octogintacentillion, nine hundred and one million octogintacentillion, two hundred and thirty-four thousand octogintacentillion, five hundred and sixty-seven octogintacentillion, eight hundred and ninety octillion septuagintacentillion, one hundred and twenty-three septillion septuagintacentillion, four hundred and fifty-six sextillion septuagintacentillion, seven hundred and eighty-nine quintillion septuagintacentillion, twelve quadrillion septuagintacentillion, three hundred and forty-five trillion septuagintacentillion, six hundred and seventy-eight billion septuagintacentillion, nine hundred and one million septuagintacentillion, two hundred and thirty-four thousand septuagintacentillion, five hundred and sixty-seven septuagintacentillion, eight hundred and ninety octillion sexagintacentillion, one hundred and twenty-three septillion sexagintacentillion, four hundred and fifty-six sextillion sexagintacentillion, seven hundred and eighty-nine quintillion sexagintacentillion, twelve quadrillion sexagintacentillion, three hundred and forty-five trillion sexagintacentillion, six hundred and seventy-eight billion sexagintacentillion, nine hundred and one million sexagintacentillion, two hundred and thirty-four thousand sexagintacentillion, five hundred and sixty-seven sexagintacentillion, eight hundred and ninety octillion quinquagintacentillion, one hundred and twenty-three septillion quinquagintacentillion, four hundred and fifty-six sextillion quinquagintacentillion, seven hundred and eighty-nine quintillion quinquagintacentillion, twelve quadrillion quinquagintacentillion, three hundred and forty-five trillion quinquagintacentillion, six hundred and seventy-eight billion quinquagintacentillion, nine hundred and one million quinquagintacentillion, two hundred and thirty-four thousand quinquagintacentillion, five hundred and sixty-seven quinquagintacentillion, eight hundred and ninety octillion quadragintacentillion, one hundred and twenty-three septillion quadragintacentillion, four hundred and fifty-six sextillion quadragintacentillion, seven hundred and eighty-nine quintillion quadragintacentillion, twelve quadrillion quadragintacentillion, three hundred and forty-five trillion quadragintacentillion, six hundred and seventy-eight billion quadragintacentillion, nine hundred and one million quadragintacentillion, two hundred and thirty-four thousand quadragintacentillion, five hundred and sixty-seven quadragintacentillion, eight hundred and ninety octillion trigintacentillion, one hundred and twenty-three septillion trigintacentillion, four hundred and fifty-six sextillion trigintacentillion, seven hundred and eighty-nine quintillion trigintacentillion, twelve quadrillion trigintacentillion, three hundred and forty-five trillion trigintacentillion, six hundred and seventy-eight billion trigintacentillion, nine hundred and one million trigintacentillion, two hundred and thirty-four thousand trigintacentillion, five hundred and sixty-seven trigintacentillion, eight hundred and ninety septillion unviginticentillion, one hundred and twenty-three sextillion unviginticentillion, four hundred and fifty-six quintillion unviginticentillion, seven hundred and eighty-nine quadrillion unviginticentillion, twelve trillion unviginticentillion, three hundred and forty-five billion unviginticentillion, six hundred and seventy-eight million unviginticentillion, nine hundred and one thousand unviginticentillion, two hundred and thirty-four unviginticentillion, five hundred and sixty-seven viginticentillion, eight hundred and ninety septillion undecicentillion, one hundred and twenty-three sextillion undecicentillion, four hundred and fifty-six quintillion undecicentillion, seven hundred and eighty-nine quadrillion undecicentillion, twelve trillion undecicentillion, three hundred and forty-five billion undecicentillion, six hundred and seventy-eight million undecicentillion, nine hundred and one thousand undecicentillion, two hundred and thirty-four undecicentillion, five hundred and sixty-seven decicentillion, eight hundred and ninety quintillion trescentillion, one hundred and twenty-three quadrillion trescentillion, four hundred and fifty-six trillion trescentillion, seven hundred and eighty-nine billion trescentillion, twelve million trescentillion, three hundred and forty-five thousand trescentillion, six hundred and seventy-eight trescentillion, nine hundred and one duocentillion, two hundred and thirty-four uncentillion, five hundred and sixty-seven centillion, eight hundred and ninety octillion nonagintillion, one hundred and twenty-three septillion nonagintillion, four hundred and fifty-six sextillion nonagintillion, seven hundred and eighty-nine quintillion nonagintillion, twelve quadrillion nonagintillion, three hundred and forty-five trillion nonagintillion, six hundred and seventy-eight billion nonagintillion, nine hundred and one million nonagintillion, two hundred and thirty-four thousand nonagintillion, five hundred and sixty-seven nonagintillion, eight hundred and ninety octillion octogintillion, one hundred and twenty-three septillion octogintillion, four hundred and fifty-six sextillion octogintillion, seven hundred and eighty-nine quintillion octogintillion, twelve quadrillion octogintillion, three hundred and forty-five trillion octogintillion, six hundred and seventy-eight billion octogintillion, nine hundred and one million octogintillion, two hundred and thirty-four thousand octogintillion, five hundred and sixty-seven octogintillion, eight hundred and ninety octillion septuagintillion, one hundred and twenty-three septillion septuagintillion, four hundred and fifty-six sextillion septuagintillion, seven hundred and eighty-nine quintillion septuagintillion, twelve quadrillion septuagintillion, three hundred and forty-five trillion septuagintillion, six hundred and seventy-eight billion septuagintillion, nine hundred and one million septuagintillion, two hundred and thirty-four thousand septuagintillion, five hundred and sixty-seven septuagintillion, eight hundred and ninety octillion sexagintillion, one hundred and twenty-three septillion sexagintillion, four hundred and fifty-six sextillion sexagintillion, seven hundred and eighty-nine quintillion sexagintillion, twelve quadrillion sexagintillion, three hundred and forty-five trillion sexagintillion, six hundred and seventy-eight billion sexagintillion, nine hundred and one million sexagintillion, two hundred and thirty-four thousand sexagintillion, five hundred and sixty-seven sexagintillion, eight hundred and ninety octillion quinquagintillion, one hundred and twenty-three septillion quinquagintillion, four hundred and fifty-six sextillion quinquagintillion, seven hundred and eighty-nine quintillion quinquagintillion, twelve quadrillion quinquagintillion, three hundred and forty-five trillion quinquagintillion, six hundred and seventy-eight billion quinquagintillion, nine hundred and one million quinquagintillion, two hundred and thirty-four thousand quinquagintillion, five hundred and sixty-seven quinquagintillion, eight hundred and ninety octillion quadragintillion, one hundred and twenty-three septillion quadragintillion, four hundred and fifty-six sextillion quadragintillion, seven hundred and eighty-nine quintillion quadragintillion, twelve quadrillion quadragintillion, three hundred and forty-five trillion quadragintillion, six hundred and seventy-eight billion quadragintillion, nine hundred and one million quadragintillion, two hundred and thirty-four thousand quadragintillion, five hundred and sixty-seven quadragintillion, eight hundred and ninety noventrigintillion, one hundred and twenty-three octotrigintillion, four hundred and fifty-six septentrigintillion, seven hundred and eighty-nine sestrigintillion, twelve quinquatrigintillion, three hundred and forty-five quattuortrigintillion, six hundred and seventy-eight trestrigintillion, nine hundred and one duotrigintillion, two hundred and thirty-four untrigintillion, five hundred and sixty-seven trigintillion, eight hundred and ninety novemvigintillion, one hundred and twenty-three octovigintillion, four hundred and fifty-six septemvigintillion, seven hundred and eighty-nine sesvigintillion, twelve quinquavigintillion, three hundred and forty-five quattuorvigintillion, six hundred and seventy-eight tresvigintillion, nine hundred and one duovigintillion, two hundred and thirty-four unvigintillion, five hundred and sixty-seven vigintillion, eight hundred and ninety novendecillion, one hundred and twenty-three octodecillion, four hundred and fifty-six septendecillion, seven hundred and eighty-nine sedecillion, twelve quindecillion, three hundred and forty-five quattuordecillion, six hundred and seventy-eight tredecillion, nine hundred and one duodecillion, two hundred and thirty-four undecillion, five hundred and sixty-seven decillion, eight hundred and ninety nonillion, one hundred and twenty-three octillion, four hundred and fifty-six septillion, seven hundred and eighty-nine sextillion, twelve quintillion, three hundred and forty-five quadrillion, six hundred and seventy-eight trillion, nine hundred and one billion, two hundred and thirty-four million, five hundred and sixty-seven thousand, eight hundred and ninetieth",
    ]
    );
}

